<?php

use Alix\Storage\Blog\BlogRepositoryInterface as Repository;
use Alix\Services\Validation\BlogValidator as Validator;

class BlogAdminController extends BaseController {

    protected $repository;
    protected $validator;

    public function __construct(Repository $repository, Validator $validator)
    {
        $this->repository = $repository;
        $this->validator = $validator;
        $this->beforeFilter(function(){
	        if(!Auth::user()->has_permission(38)){ return Redirect::route('admin'); }
        });
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index()
    {
        $categoriesblog = $this->repository->categoriesblog();
        
        return View::make($_ENV['admin-url'].'.blog.index', compact('categoriesblog'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create($id)
    {
        $categoryblog = CategoryBlog::findOrFail($id);
        $categoriesblog = CategoryBlog::with('lang')->get();
        $languages = \Language::all();

        return View::make($_ENV['admin-url'].'.blog.create', compact('categoryblog', 'languages', 'categoriesblog'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store()
    {
        $input = Input::all();

        if ( ! $this->validator->isValidForCreation($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échouée, veuillez vérifier les informations."]);
        }
        
        $blog = $this->repository->create($input);
        
        // TODO better way to update photos
        DB::table('photos')->where('blog_id', '=', $blog->id)->update(array('blog_id' => 0));
        // Photos
        if(isset($input['photos']))
        {
            $j = 1;
            foreach($input['photos'] as $f)
            {
            	if($cfile = PhotoU::find($f)){
	            	$cfile->blog_id = $blog->id;
	                $cfile->position = $j++;
	                $cfile->save();
            	}
            }
        }
        // Nettoyage
        $this->clean_empty_photos();

        return Redirect::route($_ENV['admin-url'].'.blog.index', $blog->categoryblog)
                       ->withNotification(['type' => 'success', "text" => "Article créé avec succès"]);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id)
    {
        $blog = $this->repository->findOrFail($id);
        $categoryblog = $blog->categoryblog;
        $categoriesblog = $this->repository->categoriesblog($blog->categoryblog);

        // Dirty
        // For Form::model
        $mypage['id'] = $blog->id;
        $mypage['category_blog_id'] = $blog->category_blog_id;
        $mypage['position'] = $blog->position;
        $mypage['published'] = $blog->published;

        foreach($blog->lang as $pl)
        {
            $mypage['title_'.$pl->language->short] = $pl->title;
            $mypage['keywords_'.$pl->language->short] = $pl->keywords;
            $mypage['description_'.$pl->language->short] = $pl->description;
            $mypage['url_'.$pl->language->short] = $pl->url;
            $mypage['text_'.$pl->language->short] = $pl->text;
            $mypage['name_'.$pl->language->short] = $pl->name;
        }

        $languages = \Language::all();
        
        return View::make($_ENV['admin-url'].'.blog.edit', compact('blog', 'miniature', 'categoryblog', 'categoriesblog', 'languages', 'mypage'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id)
    {
        $blog = $this->repository->findOrFail($id);

        $input = Input::all();

        if ( ! $this->validator->isValidForUpdate($input, $blog))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput();
        }

        $this->repository->update($input);
        
        // TODO better way to update photos
        DB::table('photos')->where('blog_id', '=', $blog->id)->update(array('blog_id' => 0));
        // Photos
        if(isset($input['photos']))
        {
            $j = 1;
            foreach($input['photos'] as $f)
            {
            	if($cfile = PhotoU::find($f)){
	            	$cfile->blog_id = $blog->id;
	                $cfile->position = $j++;
	                $cfile->save();
            	}
            }
        }
        // Nettoyage
        $this->clean_empty_photos();

        return Redirect::route($_ENV['admin-url'].'.blog.index', $blog->categoryblog->site_id)
                       ->withNotification(['type' => 'success', "text" => "Article mis à jour"]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id)
    {
        $this->repository->delete($id);

        return Redirect::back()
                       ->withNotification(['type' => 'danger', "text" => "Article supprimé"]);
    }
    
    public function removecomment()
    {
	    if (Request::ajax()){
	    
		    $input = Input::all();
		    if(!$comment = BlogComment::find($input['comment'])){return Redirect::route($_ENV['admin-url'].'.blog.index');}
		    
		    if($comment->delete()){
				echo 'yes';
			} else {
				echo 'no';
			}
	    }
    }
    
    public function publishcomment()
    {
	    if (Request::ajax()){
	    	$data=[];
		    $input = Input::all();
		    if(!$comment = BlogComment::find($input['comment'])){return Redirect::route($_ENV['admin-url'].'.blog.index');}
		    
		    if($comment->published){
			    $comment->published = 0;
			    $comment->save();
				$data['published'] = 'no';
				$data['comment'] = $comment->id;
			} else {
				$comment->published = 1;
			    $comment->save();
				$data['published'] = 'yes';
				$data['comment'] = $comment->id;
			}
			return json_encode($data);
	    }
    }
	
	public function postfile()
    {
    	$input = Input::all();
        $file = Input::file('Filedata');

        if($input['type'] == 'photo')
        {
            $upload = array('upload_dir' => public_path().'/uploads/photos/blog/');
            $type = 'PhotoU';
            $filename = uniqid().'-'.substr(GeneralFunctions::cleanstring($file->getClientOriginalName()),0,-3).'.'.$file->getClientOriginalExtension();
        }
        
        if($file->move($upload['upload_dir'], $filename))
        {
            $newfile = $type::create(array(
                'name' => $filename
            ));

            if($input['type'] == 'photo')
            {
                \Resizer::open($upload['upload_dir'] . $filename)
                    ->resize(450, 450)
                    ->save($upload['upload_dir'].'small/'.$filename);

                $url_to_asset = URL::route('photoblog', ['200', '100', $filename]);
            }

            return $newfile->id.'|'.$url_to_asset;
        }
        else
        {
            return false;
        }
    }

}