<?php

use Alix\Storage\CategoryBlog\CategoryBlogRepositoryInterface as Repository;
use Alix\Services\Validation\CategoryBlogValidator as Validator;

class CategoriesBlogController extends BaseController {

    protected $repository;

    protected $validator;

    public function __construct(Repository $repository, Validator $validator)
    {
        $this->repository = $repository;

        $this->validator = $validator;
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index()
    {
        $categoriesblog = $this->repository->all();

        return View::make($_ENV['admin-url'].'.categoriesblog.index', compact('categoriesblog'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        $languages = \Language::all();

        return View::make($_ENV['admin-url'].'.categoriesblog.create', compact('languages'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store()
    {
        $input = Input::all();

        if ( ! $this->validator->isValidForCreation($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échouée, veuillez vérifier les informations."]);
        }

        $categoryblog = $this->repository->create($input);

        return Redirect::route($_ENV['admin-url'].'.categoriesblog.index', $categoryblog->site_id)
                       ->withNotification(['type' => 'success', "text" => "Catégorie du blog créée"]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id)
    {
        $categoryblog = $this->repository->findOrFail($id);
        $site = $categoryblog->site;

        // Dirty
        // For Form::model
        $mycategory['id'] = $categoryblog->id;
        $mycategory['position'] = $categoryblog->position;

        foreach($categoryblog->lang as $cl)
        {
            $mycategory['name_'.$cl->language->short] = $cl->name;
            $mycategory['keywords_'.$cl->language->short] = $cl->keywords;
            $mycategory['description_'.$cl->language->short] = $cl->description;
        }

        $languages = \Language::all();

        return View::make($_ENV['admin-url'].'.categoriesblog.edit', compact('categoryblog', 'languages', 'mycategory', 'site'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id)
    {
        $categoryblog = $this->repository->findOrFail($id);

        $input = Input::all();

        if ( ! $this->validator->isValidForUpdate($input, $categoryblog))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput();
        }

        $this->repository->update($input);

        return Redirect::route($_ENV['admin-url'].'.categoriesblog.index', $categoryblog->site_id)
                       ->withNotification(['type' => 'success', "text" => "Catégorie du blog mise à jour"]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id)
    {

        // Can be improved
        $categoryblog = $this->repository->findOrFail($id);

        $this->repository->delete($id);

        return Redirect::back()
                       ->withNotification(['type' => 'danger', "text" => "Catégorie du blog supprimée"]);
    }

}