<?php

use Alix\Storage\Category\CategoryRepositoryInterface as Repository;
use Alix\Services\Validation\CategoryValidator as Validator;

class CategoriesController extends BaseController {

    protected $repository;

    protected $validator;

    public function __construct(Repository $repository, Validator $validator)
    {
        $this->repository = $repository;
        $this->validator = $validator;
        $this->beforeFilter(function(){
	        if(!Auth::user()->has_permission(38)){ return Redirect::route('admin'); }
        });
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index()
    {
        $categories = $this->repository->all();

        return View::make($_ENV['admin-url'].'.categories.index', compact('categories'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        $languages = \Language::all();
        
        $categories = $this->create_select();

        return View::make($_ENV['admin-url'].'.categories.create', compact('languages', 'categories'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store()
    {
        $input = Input::all();

        if ( ! $this->validator->isValidForCreation($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échouée, veuillez vérifier les informations."]);
        }

        $category = $this->repository->create($input);

        return Redirect::route($_ENV['admin-url'].'.categories.index', $category->site_id)
                       ->withNotification(['type' => 'success', "text" => "Catégorie créée"]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id)
    {
        $category = $this->repository->findOrFail($id);
        $site = $category->site;
        
        $categories = $this->create_select();

        // Dirty
        // For Form::model
        $mycategory['id'] = $category->id;
        $mycategory['position'] = $category->position;
        $mycategory['parent_id'] = $category->parent_id;

        foreach($category->lang as $cl)
        {
            $mycategory['name_'.$cl->language->short] = $cl->name;
            $mycategory['keywords_'.$cl->language->short] = $cl->keywords;
            $mycategory['description_'.$cl->language->short] = $cl->description;
        }

        $languages = \Language::all();

        return View::make($_ENV['admin-url'].'.categories.edit', compact('category', 'categories', 'languages', 'mycategory', 'site'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id)
    {
        $category = $this->repository->findOrFail($id);

        $input = Input::all();

        if ( ! $this->validator->isValidForUpdate($input, $category))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
            	->withNotification(['type' => 'danger', "text" => "Modification échouée, veuillez vérifier les informations"]);
        }

        $this->repository->update($input);

        return Redirect::route($_ENV['admin-url'].'.categories.index', $category->site_id)
                       ->withNotification(['type' => 'success', "text" => "Catégorie mise à jour"]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id)
    {

        // Can be improved
        $category = $this->repository->findOrFail($id);

        $this->repository->delete($id);

        return Redirect::back()
                       ->withNotification(['type' => 'danger', "text" => "Catégorie supprimée"]);
    }
    
    public function create_select($except = false)
    {
       	//$categories = Category::with(array('children', 'lang'))->where('parent_id', '=', 1)->orWhere('parent_id', '=', 0)->get();
       	$categories = Category::with(array('children', 'lang'))->orderBy('position', 'ASC')->get();

        // Preping data for the select menu
        foreach ($categories as $c)
        {
            if($c->id == $except)
                continue;

            $prefix = '';
            if($c->parent_id == 0)
                $prefix = 'Racine ';
            elseif($c->parent_id == 2)
            	$prefix = '---- ';
            else
            	$prefix = '-- ';

            $select[$c->id] = $prefix . $c->getAttr('name');
        }
        
        return $select;
    }

}