<?php

use Alix\Storage\CategoryProduit\CategoryProduitRepositoryInterface as Repository;
use Alix\Services\Validation\CategoryProduitValidator as Validator;

class CategoriesProduitsController extends BaseController {

    protected $repository;
    protected $validator;

    public function __construct(Repository $repository, Validator $validator)
    {
        $this->repository = $repository;
        $this->validator = $validator;
        $this->beforeFilter(function(){
	        if(!Auth::user()->has_permission(47)){ return Redirect::route('admin'); }
        });
    }
    
    public function index()
    {
        $categories = $this->repository->all();

        return View::make($_ENV['admin-url'].'.categoriesproduits.index', compact('categories'));
    }
    
    public function create()
    {
        $languages = \Language::all();
        
        $categories = $this->create_select();
        $pages = \Page::published()->get();

        return View::make($_ENV['admin-url'].'.categoriesproduits.create', compact('languages', 'categories', 'pages'));
    }
    
    public function store()
    {
        $input = Input::all();

        if ( ! $this->validator->isValidForCreation($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échouée, veuillez vérifier les informations."]);
        }

        $category = $this->repository->create($input);
        
        // Pages associées (guides)
        if(isset($input['pages'])){$category->pages()->sync($input['pages']);}
		$category->save();
			
        // TODO better way to update photos
        DB::table('photos')->where('category_produit_id', '=', $category->id)->update(array('category_produit_id' => 0));
        // Photos
        if(isset($input['photos']))
        {
            $j = 1;
            foreach($input['photos'] as $f)
            {
            	if($cfile = PhotoU::find($f)){
                	$cfile->category_produit_id = $category->id;
                    $cfile->position = $j++;
                    $cfile->save();
            	}
            }
        }
        // Nettoyage
        $this->clean_empty_photos();

        return Redirect::route($_ENV['admin-url'].'.categoriesproduits.index', $category->site_id)
                       ->withNotification(['type' => 'success', "text" => "Catégorie créée"]);
    }
    
    public function edit($id)
    {
        $category = $this->repository->findOrFail($id);
        $site = $category->site;
        
        $categories = $this->create_select();
        $pages = \Page::published()->get();

        // Dirty
        // For Form::model
        $mycategory['id'] = $category->id;
        $mycategory['position'] = $category->position;
        $mycategory['parent_id'] = $category->parent_id;

        foreach($category->lang as $cl)
        {
            $mycategory['name_'.$cl->language->short] = $cl->name;
            $mycategory['keywords_'.$cl->language->short] = $cl->keywords;
            $mycategory['description_'.$cl->language->short] = $cl->description;
        }

        $languages = \Language::all();

        return View::make($_ENV['admin-url'].'.categoriesproduits.edit', compact('category', 'categories', 'languages', 'mycategory', 'site', 'pages'));
    }
    
    public function update($id)
    {
        $category = $this->repository->findOrFail($id);

        $input = Input::all();

        if ( ! $this->validator->isValidForUpdate($input, $category))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
            	->withNotification(['type' => 'danger', "text" => "Modification échouée, veuillez vérifier les informations"]);
        }
        
        $category = $this->repository->update($input);
        
        // Pages associées (guides)
        if(isset($input['pages'])){
        	$category->pages()->sync($input['pages']);
        	$category_pages = array();
            foreach($category->pages as $p){
            	if(in_array($p->id, $input['pages'])){
	            	$category_pages[] = $p->id;
            	}
            }
            $category->save();
        } else {
	        $pages_a_supp = DB::table('category_produit_page')->where('category_produit_id','=',$category->id)->delete();
        }
        
        // TODO better way to update photos
        DB::table('photos')->where('category_produit_id', '=', $category->id)->update(array('category_produit_id' => 0));
        // Photos
        if(isset($input['photos']))
        {
            $j = 1;
            foreach($input['photos'] as $f)
            {
            	if($cfile = PhotoU::find($f)){
                	$cfile->category_produit_id = $category->id;
                    $cfile->position = $j++;
                    $cfile->save();
            	}
            }
        }
        // Nettoyage
        $this->clean_empty_photos();

        return Redirect::route($_ENV['admin-url'].'.categoriesproduits.index', $category->site_id)
                       ->withNotification(['type' => 'success', "text" => "Catégorie mise à jour"]);
    }
    
    public function destroy($id)
    {
        $category = $this->repository->findOrFail($id);

        $this->repository->delete($id);

        return Redirect::back()
                       ->withNotification(['type' => 'danger', "text" => "Catégorie supprimée"]);
    }
    
    public function create_select($except = false)
    {
       	//$categories = Category::with(array('children', 'lang'))->where('parent_id', '=', 1)->orWhere('parent_id', '=', 0)->get();
       	$categories = CategoryProduit::with(array('children', 'lang'))->orderBy('position', 'ASC')->get();

        // Preping data for the select menu
        foreach ($categories as $c)
        {
            if($c->id == $except)
                continue;

            $prefix = '';
            if($c->parent_id == 0)
                $prefix = 'Racine ';
            elseif($c->parent_id == 2)
            	$prefix = '---- ';
            else
            	$prefix = '-- ';

            $select[$c->id] = $prefix . $c->getAttr('name');
        }
        
        return $select;
    }
    
    public function postfile()
    {
    	$input = Input::all();
        $file = Input::file('Filedata');

        $upload = array('upload_dir' => public_path().'/uploads/photos/category_produit/');
        $type = 'PhotoU';
        $filename = uniqid().'-'.substr(GeneralFunctions::cleanstring($file->getClientOriginalName()),0,-3).'.'.$file->getClientOriginalExtension();
        
        if($file->move($upload['upload_dir'], $filename))
        {
            $newfile = $type::create(array(
            	'name' => $filename
            ));
            
            \Resizer::open($upload['upload_dir'] . $filename)
                ->resize(450, 450)
                ->save($upload['upload_dir'].'small/'.$filename);

            $url_to_asset = URL::route('photocategoryproduit', ['200', '100', $filename]);

            return $newfile->id.'|'.$url_to_asset;
        }
        else
        {
            return false;
        }
    }

}