<?php

use Alix\Services\Validation\OffreValidator as Validator;

class OffresController extends \BaseController {
	
	protected $validator;

    public function __construct(Validator $validator)
    {
        $this->validator = $validator;
        $this->beforeFilter(function(){
	        if(!Auth::user()->has_permission(45)){ return Redirect::route('admin'); }
        });
    }
    
    public function index()
	{
		$offres = Offre::all();
		return View::make($_ENV['admin-url'].'.offres.index', compact('offres'));
	}
	
	public function create()
	{
		$languages = \Language::all();
		$offres = Offre::published()->get();
		return View::make($_ENV['admin-url'].'.offres.create', compact('languages', 'offres'));
	}

	public function show($id)
	{
		if(!$offre = Offre::find($id)){return Redirect::route($_ENV['admin-url'].'.offres.index');}
		
		$languages = \Language::all();
		$offres = Offre::published()->where('id','!=',$offre->id)->get();
		
		return View::make($_ENV['admin-url'].'.offres.edit', compact('offre', 'languages', 'offres'));
	}
	
	public function store()
	{
		$input = Input::all();
		if( ! isset($input['published']))
            $input['published'] = 0;
        
        if ( ! $this->validator->isValidForCreation($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échouée, veuillez vérifier les informations."]);
        }
        else
        {
			$offre = Offre::create($input);
			
			foreach(\Language::all() as $sl)
	        {
	            $input_lang = [
					'offre_id' 				=> $offre->id,
					'language_id' 			=> $sl->id,
	                'titre' 				=> $input['titre_'.$sl->short],
	                'lieu_travail' 			=> $input['lieu_travail_'.$sl->short],
	                'besoin' 				=> $input['besoin_'.$sl->short],
					'desc_short' 			=> $input['desc_short_'.$sl->short],
					'desc' 					=> $input['desc_'.$sl->short],
					'meta_titre'			=> $input['meta_titre_'.$sl->short],
					'meta_desc' 			=> $input['meta_desc_'.$sl->short],
	            ];
	            OffreLang::create($input_lang);
	        }
	        
	        // Photos
            DB::table('photos')->where('offre_id', '=', $offre->id)->update(array('offre_id' => 0));
            if(isset($input['photos']))
            {
                $j = 1;
                foreach($input['photos'] as $f)
                {
                	if($cfile = PhotoU::find($f)){
	                	$cfile->offre_id = $offre->id;
	                    $cfile->position = $j++;
	                    $cfile->save();
                	}
                }
            }
            // Files
            DB::table('files')->where('offre_id', '=', $offre->id)->update(array('offre_id' => 0));
            if(isset($input['files']))
            {
                $j = 1;
                foreach($input['files'] as $f)
                {
                	if($cfile = FileU::find($f)){
	                    $cfile->offre_id = $offre->id;
	                    $cfile->visible = 'public';
	                    $cfile->language = $input['language_'.$f];
	                    $cfile->position = $j++;
	                    $cfile->save();
	                }
                }
            }
            // Nettoyage
            $this->clean_empty_photos();
            $this->clean_empty_files();
            
            return Redirect::route($_ENV['admin-url'].'.offres.index')
            			->withNotification(['type'=>'success', 'text'=>'L\'offre d\'emploi <b>'.ucfirst($offre->getAttr('titre')).'</b> a bien été créé.']);
        }
	}
	
	public function update($id)
    {
		if(!$offre = Offre::find($id)){return Redirect::route($_ENV['admin-url'].'.offres.index');}
        
        $input = Input::all();
        if( ! isset($input['published']))
            $input['published'] = 0;
        
    	if ( ! $this->validator->isValidForUpdate($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échoué, veuillez vérifier les informations."]);
        }
        else
        {
	        $offre->update($input);
        	
			foreach($offre->lang as $sl)
	        {
	            $input_lang = [
	                'titre' 				=> $input['titre_'.$sl->language->short],
	                'lieu_travail' 			=> $input['lieu_travail_'.$sl->language->short],
	                'besoin'	 			=> $input['besoin_'.$sl->language->short],
					'desc_short' 			=> $input['desc_short_'.$sl->language->short],
					'desc' 					=> $input['desc_'.$sl->language->short],
					'meta_titre'			=> $input['meta_titre_'.$sl->language->short],
					'meta_desc' 			=> $input['meta_desc_'.$sl->language->short],
	            ];
	            $sl->update($input_lang);
	        }
	        
	        // TODO better way to update photos
            DB::table('photos')->where('offre_id', '=', $offre->id)->update(array('offre_id' => 0));
            // Photos
            if(isset($input['photos']))
            {
                $j = 1;
                foreach($input['photos'] as $f)
                {
                	if($cfile = PhotoU::find($f)){
	                	$cfile->offre_id = $offre->id;
	                    $cfile->position = $j++;
	                    $cfile->save();
                	}
                }
            }
            // Files
            DB::table('files')->where('offre_id', '=', $offre->id)->update(array('offre_id' => 0));
            if(isset($input['files']))
            {
                $j = 1;
                foreach($input['files'] as $f)
                {
                	if($cfile = FileU::find($f)){
	                    $cfile->offre_id = $offre->id;
	                    $cfile->visible = 'public';
	                    $cfile->language = $input['language_'.$f];
	                    $cfile->position = $j++;
	                    $cfile->save();
	                }
                }
            }
            // Nettoyage
            $this->clean_empty_photos();
            $this->clean_empty_files();
            
			return Redirect::route($_ENV['admin-url'].'.offres.index')
                           ->withNotification(['type' => 'success', "text" => "L'offre d'emploi a bien été mise à jour."]);
        }
    }
	
	public function destroy($id)
	{
		if(!$offre = Offre::find($id)){return Redirect::route($_ENV['admin-url'].'.offres.index');}

		$offre->delete();
		
		return Redirect::back()->withNotification(['type' => 'danger', "text" => "Offre d'emploi upprimée avec succès!"]);
	}
	
	public function postfile()
    {
    	$input = Input::all();
        $file = Input::file('Filedata');

        if($input['type'] == 'photo')
        {
            $upload = array('upload_dir' => public_path().'/uploads/photos/events/');
            $type = 'PhotoU';
            $filename = uniqid().'-'.substr(GeneralFunctions::cleanstring($file->getClientOriginalName()),0,-3).'.'.$file->getClientOriginalExtension();
        }
        elseif($input['type'] == 'file')
        {
            $upload = array('upload_dir' => public_path().'/uploads/files/documents/');
            $type = 'FileU';
            $filename = uniqid().'-'.substr(GeneralFunctions::cleanstring($file->getClientOriginalName()),0,-3).'.'.$file->getClientOriginalExtension();
        }
        
        if($file->move($upload['upload_dir'], $filename))
        {
            $newfile = $type::create(array(
            	'name' => $filename
            ));
            
            $url_to_asset = URL::asset('/uploads/files/documents/'.$filename);

            if($input['type'] == 'photo')
            {
                \Resizer::open($upload['upload_dir'] . $filename)
                    ->resize(450, 450)
                    ->save($upload['upload_dir'].'small/'.$filename);

                $url_to_asset = URL::route('photooffre', ['200', '100', $filename]);
            }

            return $newfile->id.'|'.$url_to_asset;
        }
        else
        {
            return false;
        }
    }
	
}