<?php

use Alix\Storage\Page\PageRepositoryInterface as Repository;
use Alix\Services\Validation\PageValidator as Validator;

class PagesController extends BaseController {

    protected $repository;

    protected $validator;

    public function __construct(Repository $repository, Validator $validator)
    {
        $this->repository = $repository;
        $this->validator = $validator;
        $this->beforeFilter(function(){
	        if(!Auth::user()->has_permission(38)){ return Redirect::route('admin'); }
        });
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index()
    {
        $categories = $this->repository->categories();

        return View::make($_ENV['admin-url'].'.pages.index', compact('categories'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create($id)
    {
        $category = Category::findOrFail($id);
        $categoryliaison = Category::findOrFail($id);
        $categoryliaison = $categoryliaison->id;
        $categories = Category::with('lang')->where('parent_id','!=',0)->orderBy('position', 'ASC')->get();
        $languages = \Language::all();

        return View::make($_ENV['admin-url'].'.pages.create', compact('category', 'categoryliaison', 'languages', 'categories'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store()
    {
        $input = Input::all();

        if ( ! $this->validator->isValidForCreation($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échouée, veuillez vérifier les informations."]);
        }

        $page = $this->repository->create($input);

        return Redirect::route($_ENV['admin-url'].'.pages.index', $page->category->site_id)
                       ->withNotification(['type' => 'success', "text" => "Page créée"]);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id)
    {
        $page = $this->repository->findOrFail($id);
        $category = $page->category;
        $categoryliaison = $page->liaisoncategory_id;
        $categories = $this->repository->categories($page->category->site_id);

        // Dirty
        // For Form::model
        $mypage['id'] = $page->id;
        $mypage['category_id'] = $page->category_id;
        $mypage['position'] = $page->position;
        $mypage['published'] = $page->published;

        foreach($page->lang as $pl)
        {
            $mypage['title_'.$pl->language->short] = $pl->title;
            $mypage['keywords_'.$pl->language->short] = $pl->keywords;
            $mypage['description_'.$pl->language->short] = $pl->description;
            $mypage['url_'.$pl->language->short] = $pl->url;
            $mypage['text_'.$pl->language->short] = $pl->text;
            $mypage['name_'.$pl->language->short] = $pl->name;
        }

        $languages = \Language::all();
        
        if($page->id==17){
	        $zones = Zone::published()->where('type','=','continent')->orderBy('position','ASC')->orderBy('address','ASC')->get();
        } else {
	        $zones = [];
        }

        return View::make($_ENV['admin-url'].'.pages.edit', compact('page', 'category', 'categoryliaison', 'categories', 'languages', 'mypage', 'site', 'zones'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id)
    {
        $page = $this->repository->findOrFail($id);

        $input = Input::all();

        if ( ! $this->validator->isValidForUpdate($input, $page))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput();
        }

        $this->repository->update($input);

        return Redirect::route($_ENV['admin-url'].'.pages.index', $page->category->site_id)
                       ->withNotification(['type' => 'success', "text" => "Page mise à jour"]);
    }
    
    public function setorder()
	{
		if (Request::ajax())
		{
			$input = Input::all();
		    if(!$page = Page::find($input['id_page'])){return 'error';}
			
			$page->update(array('position' => $input['position']));
		}
	
	}
	
	public function setorderdest()
	{
		if (Request::ajax())
		{
			$input = Input::all();
		    if(!$zone = Zone::find($input['id_dest'])){return 'error';}
			
			$zone->update(array('position' => $input['position']));
		}
	
	}

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id)
    {
        $this->repository->delete($id);

        return Redirect::back()
                       ->withNotification(['type' => 'danger', "text" => "Page supprimée"]);
    }

}