<?php

use Alix\Services\Validation\PictoValidator as Validator;

class PartenairesController extends \BaseController {
	
	protected $validator;

    public function __construct(Validator $validator)
    {
        $this->validator = $validator;
        $this->beforeFilter(function(){
	        if(!Auth::user()->has_permission(44)){ return Redirect::route('admin'); }
        });
    }
    
    public function index()
	{
		$pictos = Partenaire::all();
		return View::make($_ENV['admin-url'].'.partenaires.index', compact('pictos'));
	}
	
	public function create()
	{
		$languages = \Language::all();
		return View::make($_ENV['admin-url'].'.partenaires.create', compact('languages'));
	}
	
	public function store()
	{
		$input = Input::all();
        
        if ( ! $this->validator->isValidForCreation($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échouée, veuillez vérifier les informations."]);
        }
        else
        {
			$picto = Partenaire::create($input);
			
			foreach(\Language::all() as $sl)
	        {
	            $input_lang = [
					'partenaire_id' => $picto->id,
					'language_id' => $sl->id,
	                'name' => $input['name_'.$sl->short],
	                'desc' => $input['desc_'.$sl->short],
	            ];
	            PartenaireLang::create($input_lang);
	        }
			
			$this->postphoto($picto->id);
			
            return Redirect::route($_ENV['admin-url'].'.partenaires.index')
            			->withNotification(['type'=>'success', 'text'=>'Ce partenaire a bien été ajoutée']);
        }
	}

	public function show($id)
	{
		if(!$picto = Partenaire::find($id)){return Redirect::route($_ENV['admin-url'].'.partenaires.index');}
		
		$languages = \Language::all();
		
		$myslide = array();
		$myslide['photo'] = $picto->logo;
		$myslide['url'] = $picto->url;
		$myslide['target'] = $picto->target;

		foreach($picto->lang as $sl)
        {
            $myslide['name_'.$sl->language->short] = $sl->name;
            $myslide['desc_'.$sl->language->short] = $sl->desc;
        }
		
		// Miniature
		$filename = $picto->logo;
        $upload_dir = public_path().'/uploads/photos/quartiers/';
        if(is_file($upload_dir.$filename)){
            $miniature = asset('/uploads/photos/quartiers/'.$filename);
        }
		else $miniature="";
		
		return View::make($_ENV['admin-url'].'.partenaires.edit', compact('picto', 'languages', 'myslide', 'miniature'));
	}
	
	public function update($id)
    {
		if(!$picto = Partenaire::find($id)){return Redirect::route($_ENV['admin-url'].'.partenaires.index');}
        
        $input = Input::all();
        
    	if ( ! $this->validator->isValidForUpdate($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échoué, veuillez vérifier les informations."]);
        }
        else
        {
        	$picto->update($input);
						
			foreach($picto->lang as $sl)
	        {
	            $input_lang = [
					'name' => $input['name_'.$sl->language->short],
					'desc' => $input['desc_'.$sl->language->short]
	            ];
	            $sl->update($input_lang);
	        }
			
			$this->postphoto($id);
			
			return Redirect::route($_ENV['admin-url'].'.partenaires.index')
                           ->withNotification(['type' => 'success', "text" => "Cet aménagement a bien été mis à jour"]);
        }
    }
	
	public function destroy($id)
	{
		if(!$picto = Partenaire::find($id)){return Redirect::route($_ENV['admin-url'].'.partenaires.index');}
		
		if($picto->logo != "") {
			$filename = public_path().'/uploads/photos/quartiers/'.$picto->logo;
			if(File::exists($filename)){
				File::delete($filename);
			}
		}

		$picto->delete();
		
		return Redirect::back()
						->withNotification(['type' => 'danger', "text" => "Pictogramme supprimé avec succès!"]);
	}
	
	public function postphoto($id)
    {
    	$input = Input::all();
        $file = Input::file('photo');
		
		if($file) {
		
			$upload = array('upload_dir' => public_path().'/uploads/photos/quartiers/');
			$filename = uniqid().'-'.substr(GeneralFunctions::cleanstring($file->getClientOriginalName()),0,-3).'.'.$file->getClientOriginalExtension();
		
			if(strtolower($file->getClientOriginalExtension())=='jpg' || strtolower($file->getClientOriginalExtension())=='jpeg' || strtolower($file->getClientOriginalExtension())=='png')
			{	
				if($file->move($upload['upload_dir'], $filename))
				{
					$picto = Partenaire::find($id);
					$picto['logo'] = $filename;
					$picto->save();
					return $filename;
				}
				else return false;
			}
			else return false;
		}

    }
    
    public function removephotopicto()
	{
		if (Request::ajax())
		{
			$input = Input::all();
		    if(!$picto = Partenaire::find($input['id_picto'])){return 'no';}
		    
			$filename = public_path().'/uploads/photos/quartiers/'.$picto->logo;
			
		    $picto->logo = '';
		    $picto->save();
		    
			if(File::exists($filename)){
				File::delete($filename);
				return 'yes';
			} else {
				return 'no';
			}
		}
	}
	
}