<?php

use Alix\Services\Validation\ProduitValidator as Validator;

class ProduitsController extends \BaseController {
	
	protected $validator;

    public function __construct(Validator $validator)
    {
        $this->validator = $validator;
        $this->beforeFilter(function(){
	        if(!Auth::user()->has_permission(47)){ return Redirect::route('admin'); }
        });
    }
    
    public function index()
	{
		$produits = \Produit::all();
		return View::make($_ENV['admin-url'].'.produits.index', compact('produits'));
	}
	
	public function create()
	{
		$languages = \Language::all();
		$produits = \Produit::published()->get();
		$categories = \CategoryProduit::where('parent_id','!=',0)->get();
		return View::make($_ENV['admin-url'].'.produits.create', compact('languages', 'produits', 'categories'));
	}

	public function show($id)
	{
		if(!$produit = \Produit::find($id)){return Redirect::route($_ENV['admin-url'].'.produits.index');}
		
		foreach($produit->lang as $pl)
        {
            $mypage['name_'.$pl->language->short] = $pl->name;
            $mypage['dimensions_'.$pl->language->short] = $pl->dimensions;
            $mypage['desc_'.$pl->language->short] = $pl->desc;
        }
        
		$languages = \Language::all();
		$produits = \Produit::published()->where('id','!=',$produit->id)->get();
		$categories = \CategoryProduit::where('parent_id','!=',0)->get();
		
		return View::make($_ENV['admin-url'].'.produits.edit', compact('produit', 'languages', 'produits', 'mypage', 'categories'));
	}
	
	public function store()
	{
		$input = Input::all();
		
		if( ! isset($input['published']))
            $input['published'] = 0;
        if( ! isset($input['nouveaute']))
            $input['nouveaute'] = 0;
        if( ! isset($input['promotion']))
            $input['promotion'] = 0;
        
        if ( ! $this->validator->isValidForCreation($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échouée, veuillez vérifier les informations."]);
        }
        else
        {
			$produit = \Produit::create($input);
			
			if(isset($input['categories'])){$produit->categories()->sync($input['categories']);}
			$produit->save();
			
			foreach(\Language::all() as $sl)
	        {
	            $input_lang = [
					'produit_id' 			=> $produit->id,
					'language_id' 			=> $sl->id,
	                'name' 					=> $input['name_'.$sl->short],
	                'dimensions' 			=> $input['dimensions_'.$sl->short],
					'desc' 					=> $input['desc_'.$sl->short],
	            ];
	            \ProduitLang::create($input_lang);
	        }
	        
	        // Photos
            DB::table('photos')->where('produit_id', '=', $produit->id)->update(array('produit_id' => 0));
            if(isset($input['photos']))
            {
                $j = 1;
                foreach($input['photos'] as $f)
                {
                	if($cfile = PhotoU::find($f)){
	                	$cfile->produit_id = $produit->id;
	                    $cfile->position = $j++;
	                    $cfile->save();
                	}
                }
            }
            // Files
            DB::table('files')->where('produit_id', '=', $produit->id)->update(array('produit_id' => 0));
            if(isset($input['files']))
            {
                $j = 1;
                foreach($input['files'] as $f)
                {
                	if($cfile = FileU::find($f)){
	                    $cfile->produit_id = $produit->id;
	                    $cfile->visible = 'public';
	                    $cfile->language = $input['language_'.$f];
	                    $cfile->position = $j++;
	                    $cfile->save();
	                }
                }
            }
            // TODO better way to update realisations
            DB::table('realisations')->where('produit_id', '=', $produit->id)->update(array('produit_id' => 0));
            // Réalisations
            if(isset($input['realisations']))
            {
                $j = 1;
                foreach($input['realisations'] as $f)
                {
                	if($cfile = Realisation::find($f)){
	                	$cfile->produit_id = $produit->id;
	                    $cfile->position = $j++;
	                    $cfile->save();
	                    // Lang
	                    DB::table('realisations_lang')->where('realisation_id', '=', $cfile->id)->delete();
	                    $l = 0;
	                    foreach(\Language::all() as $sl)
				        {
				            $input_lang = [
								'realisation_id' 		=> $cfile->id,
								'language_id' 			=> $sl->id,
								'desc' 					=> $input['rea'][$cfile->id]['rdesc_'.$sl->short],
				            ];
				            \RealisationLang::create($input_lang);
				            $l++;
				        }
                	}
                }
            }
            // Nettoyage
            $this->clean_empty_photos();
            $this->clean_empty_files();
            
            return Redirect::route($_ENV['admin-url'].'.produits.index')
            			->withNotification(['type'=>'success', 'text'=>'Le produit <b>'.ucfirst($produit->getAttr('name')).'</b> a bien été créé.']);
        }
	}
	
	public function update($id)
    {
		if(!$produit = \Produit::find($id)){return Redirect::route($_ENV['admin-url'].'.produits.index');}
        
        $input = Input::all();
        
        if( ! isset($input['published']))
            $input['published'] = 0;
        if( ! isset($input['nouveaute']))
            $input['nouveaute'] = 0;
        if( ! isset($input['promotion']))
            $input['promotion'] = 0;
        
    	if ( ! $this->validator->isValidForUpdate($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échoué, veuillez vérifier les informations."]);
        }
        else
        {
	        $produit->update($input);
	        
	        if(isset($input['categories'])){
	        	$produit->categories()->sync($input['categories']);
	        	$produit_categories = array();
	            foreach($produit->categories as $p){
	            	if(in_array($p->id, $input['categories'])){
		            	$produit_categories[] = $p->id; 
	            	}
	            }
	            $produit->save();
	        } else {
		        $categories_a_supp = DB::table('category_produit_produit')->where('produit_id','=',$produit->id)->delete();
	        }
        	
			foreach($produit->lang as $sl)
	        {
	            $input_lang = [
	                'name' 					=> $input['name_'.$sl->language->short],
	                'dimensions' 			=> $input['dimensions_'.$sl->language->short],
	                'desc'	 				=> $input['desc_'.$sl->language->short],
	            ];
	            $sl->update($input_lang);
	        }
	        
	        // TODO better way to update photos
            DB::table('photos')->where('produit_id', '=', $produit->id)->update(array('produit_id' => 0));
            // Photos
            if(isset($input['photos']))
            {
                $j = 1;
                foreach($input['photos'] as $f)
                {
                	if($cfile = PhotoU::find($f)){
	                	$cfile->produit_id = $produit->id;
	                    $cfile->position = $j++;
	                    $cfile->save();
                	}
                }
            }
            // Files
            DB::table('files')->where('produit_id', '=', $produit->id)->update(array('produit_id' => 0));
            if(isset($input['files']))
            {
                $j = 1;
                foreach($input['files'] as $f)
                {
                	if($cfile = FileU::find($f)){
	                    $cfile->produit_id = $produit->id;
	                    $cfile->visible = 'public';
	                    $cfile->language = $input['language_'.$f];
	                    $cfile->position = $j++;
	                    $cfile->save();
	                }
                }
            }
            // TODO better way to update realisations
            DB::table('realisations')->where('produit_id', '=', $produit->id)->update(array('produit_id' => 0));
            // Réalisations
            if(isset($input['realisations']))
            {
                $j = 1;
                foreach($input['realisations'] as $f)
                {
                	if($cfile = Realisation::find($f)){
	                	$cfile->produit_id = $produit->id;
	                    $cfile->position = $j++;
	                    $cfile->save();
	                    // Lang
	                    DB::table('realisations_lang')->where('realisation_id', '=', $cfile->id)->delete();
	                    $l = 0;
	                    foreach(\Language::all() as $sl)
				        {
				            $input_lang = [
								'realisation_id' 		=> $cfile->id,
								'language_id' 			=> $sl->id,
								'desc' 					=> $input['rea'][$cfile->id]['rdesc_'.$sl->short],
				            ];
				            \RealisationLang::create($input_lang);
				            $l++;
				        }
                	}
                }
            }
            // Nettoyage
            $this->clean_empty_photos();
            $this->clean_empty_files();
            
			return Redirect::route($_ENV['admin-url'].'.produits.index')
                           ->withNotification(['type' => 'success', "text" => "Le produit a bien été mise à jour."]);
        }
    }
	
	public function destroy($id)
	{
		if(!$produit = \Produit::find($id)){return Redirect::route($_ENV['admin-url'].'.produits.index');}

		$produit->delete();
		
		return Redirect::back()->withNotification(['type' => 'danger', "text" => "Produit supprimé avec succès!"]);
	}
	
	public function postfile()
    {
    	$input = Input::all();
        $file = Input::file('Filedata');

        if($input['type'] == 'photo')
        {
            $upload = array('upload_dir' => public_path().'/uploads/photos/produits/');
            $type = 'PhotoU';
            $filename = uniqid().'-'.substr(GeneralFunctions::cleanstring($file->getClientOriginalName()),0,-3).'.'.$file->getClientOriginalExtension();
        }
        elseif($input['type'] == 'realisation')
        {
	        $upload = array('upload_dir' => public_path().'/uploads/photos/realisations/');
            $type = 'Realisation';
            $filename = uniqid().'-'.substr(GeneralFunctions::cleanstring($file->getClientOriginalName()),0,-3).'.'.$file->getClientOriginalExtension();
        }
        elseif($input['type'] == 'file')
        {
            $upload = array('upload_dir' => public_path().'/uploads/files/documents/');
            $type = 'FileU';
            $filename = uniqid().'-'.substr(GeneralFunctions::cleanstring($file->getClientOriginalName()),0,-3).'.'.$file->getClientOriginalExtension();
        }
        
        if($file->move($upload['upload_dir'], $filename))
        {
            $newfile = $type::create(array(
            	'name' => $filename
            ));
            
            $url_to_asset = URL::asset('/uploads/files/documents/'.$filename);
			
			if($input['type'] == 'photo' || $input['type'] == 'realisation')
			{
				\Resizer::open($upload['upload_dir'] . $filename)
	                    ->resize(450, 450)
	                    ->save($upload['upload_dir'].'small/'.$filename);
	    	}
                    
            if($input['type'] == 'photo')
            {
            	$url_to_asset = URL::route('photoproduit', ['200', '100', $filename]);
			}
            elseif($input['type'] == 'realisation')
            {
            	$url_to_asset  = URL::route('photorealisation', ['200', '100', $filename]);
            	$url_to_asset .= '|';
            	$l=0;
            	foreach(\Language::all() as $language){
	            	$url_to_asset .= '<p>'.Form::textarea('rea['.$newfile->id.'][rdesc_'.$language->short.']', NULL, ['placeholder'=>'Description '.$language->name, 'rows'=>'2', 'class'=>'form-control']).'</p>';
	            	$l++;
            	}
            }
            
            return $newfile->id.'|'.$url_to_asset;
        }
        else
        {
            return false;
        }
    }
	
}