<?php

use Alix\Services\Validation\ServiceValidator as Validator;

class ServicesController extends \BaseController {
	
	protected $validator;

    public function __construct(Validator $validator)
    {
        $this->validator = $validator;
        $this->beforeFilter(function(){
	        if(!Auth::user()->has_permission(46)){ return Redirect::route('admin'); }
        });
    }
    
    public function index()
	{
		$services = Service::all();
		return View::make($_ENV['admin-url'].'.services.index', compact('services'));
	}
	
	public function create()
	{
		$languages = \Language::all();
		$services = Service::published()->get();
		return View::make($_ENV['admin-url'].'.services.create', compact('languages', 'services'));
	}

	public function show($id)
	{
		if(!$service = Service::find($id)){return Redirect::route($_ENV['admin-url'].'.services.index');}
		
		$languages = \Language::all();
		$services = Service::published()->where('id','!=',$service->id)->get();
		
		// Miniature
		$filename = $service->background;
        $upload_dir = public_path().'/uploads/photos/annonces/';
        if(is_file($upload_dir.$filename)){
            $background = asset('/uploads/photos/annonces/'.$filename);
        }
		else $background="";
		
		return View::make($_ENV['admin-url'].'.services.edit', compact('service', 'languages', 'services', 'background'));
	}
	
	public function store()
	{
		$input = Input::all();
		if( ! isset($input['published']))
            $input['published'] = 0;
        
        if ( ! $this->validator->isValidForCreation($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échouée, veuillez vérifier les informations."]);
        }
        else
        {
			$service = Service::create($input);
			
			/* Suggestions d'annonces
			if(isset($input['annonces'])){
	        	foreach($input['annonces'] as $key=>$value){
		        	DB::table('annonce_annonce')->insert([
			        	'annonce1_id' => $annonce->id,
			        	'annonce2_id' => $value,
		        	]);
	        	}
	        }*/
			
			foreach(\Language::all() as $sl)
	        {
	            $input_lang = [
					'service_id' 			=> $service->id,
					'language_id' 			=> $sl->id,
	                'name' 					=> $input['name_'.$sl->short],
	                'sub-name' 				=> $input['sub-name_'.$sl->short],
					'desc_short' 			=> $input['desc_short_'.$sl->short],
					'desc' 					=> $input['desc_'.$sl->short],
					'meta_titre'			=> $input['meta_titre_'.$sl->short],
					'meta_desc' 			=> $input['meta_desc_'.$sl->short],
	            ];
	            ServiceLang::create($input_lang);
	        }
	        
	        $this->postphoto($service->id);
	        
	        // Photos
            DB::table('photos')->where('service_id', '=', $service->id)->update(array('service_id' => 0));
            if(isset($input['photos']))
            {
                $j = 1;
                foreach($input['photos'] as $f)
                {
                	if($cfile = PhotoU::find($f)){
	                	$cfile->service_id = $service->id;
	                    $cfile->position = $j++;
	                    $cfile->save();
                	}
                }
            }
            // Files
            DB::table('files')->where('service_id', '=', $service->id)->update(array('service_id' => 0));
            if(isset($input['files']))
            {
                $j = 1;
                foreach($input['files'] as $f)
                {
                	if($cfile = FileU::find($f)){
	                    $cfile->service_id = $service->id;
	                    $cfile->visible = 'public';
	                    $cfile->language = $input['language_'.$f];
	                    $cfile->position = $j++;
	                    $cfile->save();
	                }
                }
            }
            // Nettoyage
            $this->clean_empty_photos();
            $this->clean_empty_files();
            
            return Redirect::route($_ENV['admin-url'].'.services.index')
            			->withNotification(['type'=>'success', 'text'=>'<b>'.ucfirst($service->getAttr('name')).'</b> a bien été créé.']);
        }
	}
	
	public function update($id)
    {
		if(!$service = Service::find($id)){return Redirect::route($_ENV['admin-url'].'.services.index');}
        
        $input = Input::all();
        if( ! isset($input['published']))
            $input['published'] = 0;
        
    	if ( ! $this->validator->isValidForUpdate($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échoué, veuillez vérifier les informations."]);
        }
        else
        {
	        $service->update($input);
        	
        	/* Suggestions d'annonces
        	$annonces_a_supp = DB::table('annonce_annonce')->where('annonce1_id','=',$annonce->id)->delete();
        	if(isset($input['annonces'])){
	        	foreach($input['annonces'] as $key=>$value){
		        	DB::table('annonce_annonce')->insert([
			        	'annonce1_id' => $annonce->id,
			        	'annonce2_id' => $value,
		        	]);
	        	}
	        }*/
        	
			foreach($service->lang as $sl)
	        {
	            $input_lang = [
	                'name' 					=> $input['name_'.$sl->language->short],
	                'sub-name' 				=> $input['sub-name_'.$sl->language->short],
					'desc_short' 			=> $input['desc_short_'.$sl->language->short],
					'desc' 					=> $input['desc_'.$sl->language->short],
					'meta_titre'			=> $input['meta_titre_'.$sl->language->short],
					'meta_desc' 			=> $input['meta_desc_'.$sl->language->short],
	            ];
	            $sl->update($input_lang);
	        }
	        
	        $this->postphoto($id);
	        
	        // TODO better way to update photos
            DB::table('photos')->where('service_id', '=', $service->id)->update(array('service_id' => 0));
            // Photos
            if(isset($input['photos']))
            {
                $j = 1;
                foreach($input['photos'] as $f)
                {
                	if($cfile = PhotoU::find($f)){
	                	$cfile->service_id = $service->id;
	                    $cfile->position = $j++;
	                    $cfile->save();
                	}
                }
            }
            // Files
            DB::table('files')->where('service_id', '=', $service->id)->update(array('service_id' => 0));
            if(isset($input['files']))
            {
                $j = 1;
                foreach($input['files'] as $f)
                {
                	if($cfile = FileU::find($f)){
	                    $cfile->service_id = $service->id;
	                    $cfile->visible = 'public';
	                    $cfile->language = $input['language_'.$f];
	                    $cfile->position = $j++;
	                    $cfile->save();
	                }
                }
            }
            // Nettoyage
            $this->clean_empty_photos();
            $this->clean_empty_files();
            
			return Redirect::route($_ENV['admin-url'].'.services.index')
                           ->withNotification(['type' => 'success', "text" => "Mise à jour effectuée."]);
        }
    }
	
	public function destroy($id)
	{
		if(!$service = Service::find($id)){return Redirect::route($_ENV['admin-url'].'.services.index');}

		$service->delete();
		
		return Redirect::back()->withNotification(['type' => 'danger', "text" => "Supprimé avec succès!"]);
	}
	
	public function postfile()
    {
    	$input = Input::all();
        $file = Input::file('Filedata');

        if($input['type'] == 'photo')
        {
            $upload = array('upload_dir' => public_path().'/uploads/photos/annonces/');
            $type = 'PhotoU';
            $filename = uniqid().'-'.substr(GeneralFunctions::cleanstring($file->getClientOriginalName()),0,-3).'.'.$file->getClientOriginalExtension();
        }
        elseif($input['type'] == 'file')
        {
            $upload = array('upload_dir' => public_path().'/uploads/files/general/');
            $type = 'FileU';
            $filename = uniqid().'-'.substr(GeneralFunctions::cleanstring($file->getClientOriginalName()),0,-3).'.'.$file->getClientOriginalExtension();
        }
        
        if($file->move($upload['upload_dir'], $filename))
        {
            $newfile = $type::create(array(
            	'name' => $filename
            ));
            
            $url_to_asset = URL::asset('/uploads/files/general/'.$filename);

            if($input['type'] == 'photo')
            {
                \Resizer::open($upload['upload_dir'] . $filename)
                    ->resize(450, 450)
                    ->save($upload['upload_dir'].'small/'.$filename);

                $url_to_asset = URL::route('photoservice', ['200', '100', $filename]);
            }

            return $newfile->id.'|'.$url_to_asset;
        }
        else
        {
            return false;
        }
    }
    
    public function postphoto($id)
    {
    	$input = Input::all();
        $file = Input::file('photo');
		
		if($file) {
		
			$upload = array('upload_dir' => public_path().'/uploads/photos/annonces/');
			$filename = uniqid().'-'.substr(GeneralFunctions::cleanstring($file->getClientOriginalName()),0,-3).'.'.$file->getClientOriginalExtension();
		
			if(strtolower($file->getClientOriginalExtension())=='jpg' || strtolower($file->getClientOriginalExtension())=='jpeg' || strtolower($file->getClientOriginalExtension())=='png')
			{	
				if($file->move($upload['upload_dir'], $filename))
				{
					$service = Service::find($id);
					$service['background'] = $filename;
					$service->save();
					return $filename;
				}
				else return false;
			}
			else return false;
		}

    }
    
    public function remove_bg_service()
	{
		if (Request::ajax())
		{
			$input = Input::all();
		    if(!$service = Service::find($input['id_service'])){return 'no';}
		    
			$filename = public_path().'/uploads/photos/annonces/'.$service->background;
			
		    $service->background = '';
		    $service->save();
		    
			if(File::exists($filename)){
				File::delete($filename);
				return 'yes';
			} else {
				return 'no';
			}
		}
	}
	
}