<?php

use Alix\Services\Validation\SlideshowSlideValidator as Validator;

class SlideshowsSlidesController extends \BaseController {
	
	protected $validator;

    public function __construct(Validator $validator)
    {
        $this->validator = $validator;
        $this->beforeFilter(function(){
	        if(!Auth::user()->has_permission(38)){ return Redirect::route('admin'); }
        });
        
        $annonces = [];
        $annonces[0] = "Ne pas lier à une annonce";
        foreach(Annonce::published()->orderBy('id', 'ASC')->get() as $a){
	        $annonces[$a->id] = '#'.$a->reference.' - '.$a->getAttr('name');
        }
        $this->annonces = $annonces;
    }
	
	public function create($id)
	{
		$languages = \Language::all();
		$slideshow_id = $id;
		$annonces = $this->annonces;
		return View::make($_ENV['admin-url'].'.slideshows_slides.create', compact('languages', 'slideshow_id', 'annonces'));
	}
	
	public function store()
	{
		$input = Input::all();
        
        if ( ! $this->validator->isValidForCreation($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échouée, veuillez vérifier les informations."]);
        }
        else
        {
			$slides = SlideshowSlide::where('slideshow_id','=',$input['slideshow_id'])->get();
			if($slides->count() > 0) {
				$position = $slides->count() + 1;
			}
			else $position = 1;
		
        	$slideshow_slide = SlideshowSlide::create(array(
				'slideshow_id' => $input['slideshow_id'],
				'annonce_id' => $input['annonce_id'],
				'lien' => $input['lien'],
				'target' => $input['target'],
				'position' => $position,
			));
			
			if($slideshow_slide->annonce_id!=0){
				$slideshow_slide->lien = '';
				$slideshow_slide->photo = '';
				$slideshow_slide->save();
			}
			
			foreach(Language::all() as $language)
	        {
	            $input_lang = [
					'slideshow_slide_id' => $slideshow_slide->id,
	                'language_id' => $language->id,
	                'ligne1' => $input['ligne1_'.$language->short],
					'ligne2' => $input['ligne2_'.$language->short],
					'btn' => $input['btn_'.$language->short]
	            ];
				SlideshowSlideLang::create($input_lang);
	        }
			
			$this->postphoto($slideshow_slide->id);
			
            return Redirect::route($_ENV['admin-url'].'.slideshows.index')
            			->withNotification(['type'=>'success', 'text'=>'Ce slide a bien été ajouté']);
        }
	}

	public function show($id,$id_slide)
	{
		if(!$slide = SlideshowSlide::find($id_slide)){return Redirect::route($_ENV['admin-url'].'.slideshows.index');}
		
		$languages = \Language::all();
		$annonces = $this->annonces;
		
		$myslide = array();
		$myslide['photo'] = $slide->photo;
		$myslide['position'] = $slide->position;
		$myslide['target'] = $slide->target;

		foreach($slide->lang as $sl)
        {
            $myslide['ligne1_'.$sl->language->short] = $sl->ligne1;
			$myslide['ligne2_'.$sl->language->short] = $sl->ligne2;
			$myslide['btn_'.$sl->language->short] = $sl->btn;
        }
		
		// Miniature
		$filename = $slide->photo;
        $upload_dir = public_path().'/uploads/photos/slideshows/';
        if(is_file($upload_dir.$filename)){
            $miniature = asset('/uploads/photos/slideshows/small/'.$filename);
        }
		else $miniature="";
		
		return View::make($_ENV['admin-url'].'.slideshows_slides.edit', compact('slide', 'languages', 'myslide', 'miniature', 'annonces'));
	}
	
	public function update($id)
    {
		if(!$slide = SlideshowSlide::find($id)){return Redirect::route($_ENV['admin-url'].'.slideshows.index');}
        
        $input = Input::all();
        
    	if ( ! $this->validator->isValidForUpdate($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échoué, veuillez vérifier les informations."]);
        }
        else
        {
        	$slide->update(array(
				'lien' => $input['lien'],
				'target' => $input['target'],
				'annonce_id' => $input['annonce_id'],
			));
						
			foreach($slide->lang as $sl)
	        {
	            $input_lang = [
					'ligne1' => $input['ligne1_'.$sl->language->short],
					'ligne2' => $input['ligne2_'.$sl->language->short],
					'btn' => $input['btn_'.$sl->language->short]
	            ];
	            $sl->update($input_lang);
	        }
			
			if($slide->annonce_id!=0){
				$slide->lien = '';
				$slide->photo = '';
				$slide->save();
			}
			
			$this->postphoto($id);
			
			return Redirect::route($_ENV['admin-url'].'.slideshows.index')
                           ->withNotification(['type' => 'success', "text" => "Le carrousel a bien été mis à jour"]);
        }
    }
	
	public function destroy($id)
	{
		if(!$slide = SlideshowSlide::find($id)){return Redirect::route($_ENV['admin-url'].'.slideshows.index');}
		
		$slideshow_id = $slide->slideshow_id;
		
		if($slide->photo != "") {
			$filename = public_path().'/uploads/photos/slideshows/'.$slide->photo;
			$filename_small = public_path().'/uploads/photos/slideshows/small/'.$slide->photo;
			
			if(File::exists($filename) && File::exists($filename_small)){
				File::delete($filename);
				File::delete($filename_small);
			}
		}
		
		foreach($slide->lang as $s) {
			SlideshowSlideLang::find($s->id)->delete();
		}
				

		$slide->delete();
		
		$slides = SlideshowSlide::where('slideshow_id','=',$slideshow_id)->orderby('position', 'ASC')->get();
		
		if($slides->count() > 0) {
			$pos = 1;
			foreach($slides as $slide) {
				$slide->update(array('position' => $pos));
				$pos++;
			}
		}
		
		return Redirect::back()
						->withNotification(['type' => 'danger', "text" => "Slide supprimé"]);
	}
	
	public function postphoto($id)
    {
    	$input = Input::all();
        $file = Input::file('photo');
		
		if($file) {
		
			$upload = array('upload_dir' => public_path().'/uploads/photos/slideshows/');
			$filename = uniqid().'-'.substr(GeneralFunctions::cleanstring($file->getClientOriginalName()),0,-3).'.'.$file->getClientOriginalExtension();
		
			if(strtolower($file->getClientOriginalExtension())=='jpg' || strtolower($file->getClientOriginalExtension())=='jpeg' || strtolower($file->getClientOriginalExtension())=='png')
			{	
				if($file->move($upload['upload_dir'], $filename))
				{
					SlideshowSlide::find($id)->update(array('photo' => $filename));
					\Resizer::open($upload['upload_dir'] . $filename)
						->resize(200, 200)
						->save($upload['upload_dir'].'small/'.$filename);

					return $filename;
				}
				else return false;
			
			}
			else return false;
		}

    }
	
	public function removephotoslide()
	{
		if (Request::ajax())
		{
			$input = Input::all();
		    if(!$slide = SlideshowSlide::find($input['id_slide'])){return 'no';}
		    
			$filename = public_path().'/uploads/photos/slideshows/'.$slide->photo;
			$filename_small = public_path().'/uploads/photos/slideshows/small/'.$slide->photo;
			
		    $slide->photo = '';
		    $slide->save();
		    
			if(File::exists($filename) && File::exists($filename_small)){
				File::delete($filename);
				File::delete($filename_small);
				return 'yes';
			} else {
				return 'no';
			}
		}
	}
	
	public function setorder()
	{
		if (Request::ajax())
		{
			$input = Input::all();
		    if(!$slide = SlideshowSlide::find($input['id_slide'])){return 'error';}
			
			$slide->update(array('position' => $input['position']));
		}
	
	}
	
}