<?php

use Alix\Services\Validation\TypeAnnonceValidator as Validator;

class TypeAnnonceController extends \BaseController {
	
	protected $validator;

    public function __construct(Validator $validator)
    {
        $this->validator = $validator;
        $this->beforeFilter(function(){
	        if(!Auth::user()->has_permission(41)){ return Redirect::route('admin'); }
        });
    }
    
    public function index()
	{
		$types = TypeAnnonce::all();
		return View::make($_ENV['admin-url'].'.types_annonce.index', compact('types'));
	}
	
	public function create()
	{
		$languages = \Language::all();
		return View::make($_ENV['admin-url'].'.types_annonce.create', compact('languages'));
	}
	
	public function store()
	{
		$input = Input::all();
        
        if ( ! $this->validator->isValidForCreation($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échouée, veuillez vérifier les informations."]);
        }
        else
        {
			$type = TypeAnnonce::create([]); // $input
			
			foreach(\Language::all() as $sl)
	        {
	            $input_lang = [
					'type_annonce_id' => $type->id,
					'language_id' => $sl->id,
	                'name' => $input['name_'.$sl->short],
	            ];
	            TypeAnnonceLang::create($input_lang);
	        }
			
            return Redirect::route($_ENV['admin-url'].'.types_annonce.index')
            			->withNotification(['type'=>'success', 'text'=>'Ce type d\'annonce a bien été ajouté']);
        }
	}

	public function show($id)
	{
		if(!$type = TypeAnnonce::find($id)){return Redirect::route($_ENV['admin-url'].'.types_annonce.index');}
		
		$languages = \Language::all();
		
		$myslide = array();

		foreach($type->lang as $sl)
        {
            $myslide['name_'.$sl->language->short] = $sl->name;
        }
		
		return View::make($_ENV['admin-url'].'.types_annonce.edit', compact('type', 'languages', 'myslide'));
	}
	
	public function update($id)
    {
		if(!$type = TypeAnnonce::find($id)){return Redirect::route($_ENV['admin-url'].'.types_annonce.index');}
        
        $input = Input::all();
        
    	if ( ! $this->validator->isValidForUpdate($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échoué, veuillez vérifier les informations."]);
        }
        else
        {
        	$type->update([]); // $input
						
			foreach($type->lang as $sl)
	        {
	            $input_lang = [
					'name' => $input['name_'.$sl->language->short]
	            ];
	            $sl->update($input_lang);
	        }
			
			return Redirect::route($_ENV['admin-url'].'.types_annonce.index')
                           ->withNotification(['type' => 'success', "text" => "Ce type d\'annonce a bien été mis à jour"]);
        }
    }
	
	public function destroy($id)
	{
		if(!$type = TypeAnnonce::find($id)){return Redirect::route($_ENV['admin-url'].'.types_annonce.index');}

		$type->delete();
		
		return Redirect::back()
						->withNotification(['type' => 'danger', "text" => "Type d\'annonce supprimé avec succès!"]);
	}
	
}