<?php

use Alix\Services\Validation\UserValidator as Validator;

class UsersController extends \BaseController {
	
	protected $validator;

    public function __construct(Validator $validator)
    {
        $this->validator = $validator;
        $this->beforeFilter(function(){
		    if(!Auth::user()->has_permission(1)){ return Redirect::route('admin'); }
		});
    }
    
	public function index()
	{
		$data['users'] = User::all();
		return View::make($_ENV['admin-url'].'.users.index', $data);
	}

	public function show($id)
	{
		if(!$user = User::find($id)){return Redirect::route($_ENV['admin-url'].'.users.index');}
		$roles = Role::orderBy('name','ASC')->get();
		return View::make($_ENV['admin-url'].'.users.show', compact('user', 'roles'));
	}
	
	public function create()
	{
		$roles = Role::orderBy('name','ASC')->get();
		return View::make($_ENV['admin-url'].'.users.create', compact('roles'));
	}
	
	public function store()
	{
		$input = Input::all();
        
        if ( ! $this->validator->isValidForCreation($input, ['password'=>'required','email'=>'required|unique:users']))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échouée, veuillez vérifier les informations."]);
        }
        else
        {
        	$user = User::create(array(
                'email' => $input['email'],
                'phone' => $input['phone'],
                'first_name' => $input['first_name'],
                'last_name' => $input['last_name'],
                'password' => Hash::make($input['password']),
                'admin' => 1
            ));
            if(isset($input['roles'])){$user->roles()->sync($input['roles']);}
            $user->save();
            
            return Redirect::route($_ENV['admin-url'].'.users.index')
            			->withNotification(['type'=>'success', 'text'=>'Le client a bien été ajouté']);
        }
	}
	
	public function update($id)
    {
        if(!$user = User::find($id)){return Redirect::route($_ENV['admin-url'].'.users.index');}
        
        $input = Input::all();
        
    	if ( ! $this->validator->isValidForUpdate($input))
        {
            return Redirect::back()->withErrors($this->validator->getErrors())->withInput()
                           ->withNotification(['type' => 'danger', "text" => "La validation du formulaire a échouée, veuillez vérifier les informations."]);
        }
        else
        {
        	// Update user
            $user->email 	 = $input['email'];
            $user->first_name= $input['first_name'];
            $user->last_name = $input['last_name'];
            $user->phone 	 = $input['phone'];
            
            if(Input::get('password'))
                $user->password = $input['password'];
                
            if(isset($input['roles'])){
	            $user->roles()->sync($input['roles']);
	            $user_roles = array();
	            foreach(Auth::user()->roles as $r){
	            	if(in_array($r->id, $input['roles'])){
		            	$user_roles[] = $r->id; 
	            	}
	            }
	            $user->save();
	        } else {
		        $roles_a_supp = DB::table('role_user')->where('user_id','=',$user->id)->delete();
	        }
            
			return Redirect::route($_ENV['admin-url'].'.users.index')
                           ->withNotification(['type' => 'success', "text" => "Admin mis à jour"]);
        }
    }
	
	public function destroy($id)
	{
		if(!$user = User::find($id)){return Redirect::route($_ENV['admin-url'].'.users.index');}

		$user->delete();
		
		return Redirect::back()
						->withNotification(['type' => 'danger', "text" => "Admin supprimé"]);
	}

}