<?php

class DateFunctions {

	public static function format_year($year){
		if(strlen($year)==3 || $year>date('Y')){
			$year = substr($year,0,2);
		}
		if(strlen($year)==2){
			if($year>=0 && $year<=15){
				$year = '20'.$year;
			}
			else{
				$year = '19'.$year;
			}
		}
		return $year;
	}
	
	public static function date_ecart($date){
		$d1 = strtotime($date); 
		$d2 = strtotime(date("Y-m-d H:i:s")); 
		$diff = $d2-$d1;

		if($diff<60){
			$diff = 'il y a moins d\'une minute';
		}
		elseif($diff>=60 && $diff<120){
			$diff = 'il y a une minute';
		}
		elseif($diff>=120 && $diff<3600){
			$diff = 'il y a '.round($diff/60).' minutes';
		}
		elseif($diff>=3600 && $diff<7200){
			$diff = 'il y a une heure';
		}
		elseif($diff>=7200 && $diff<86400){
			$diff = 'il y a '.round($diff/3600).' heures';
		}
		elseif($diff>=86400 && $diff<172800){
			$diff = 'il y a un jour';
		}
		elseif($diff>=172800 && $diff<5356800){
			$diff = 'il y a '.round($diff/86400).' jours';
		}
		elseif($diff>=5356800 && $diff<31536000){
			$diff = 'il y a '.round($diff/2678400).' mois';
		}
		else{
			$diff = 'il y a plus d\'un an';
		}
		
		return $diff;
	}

	public static function date_to_mysql($date){
		// EX : 06/12/1900 -> 1900-12-06
		return substr($date,6,4).'-'.substr($date,3,2).'-'.substr($date,0,2);
	}

	public static function date_to_mysql_bis($date){
		// EX : 20140801 -> 2014 - 08 - 01
		return substr($date,0,4).'-'.substr($date,4,2).'-'.substr($date,6,2);
	}


	public static function date_to_mysql_long($date) {
		// Input : jj-mm-aaaa
		return self::date_to_mysql($date).' 00:00:00.000000';
	}

	public static function date_to_mysql_long_bis($date) {
		// EX : 20140801152326 -> 2014 - 08 - 01 15:23:26.000000
		return self::date_to_mysql_bis($date).' '.substr($date,8,2).':'.substr($date,10,2).':'.substr($date,12,2).'.000000';
	}
	
	public static function format_date($date, $delimiteur = '/'){
		if(round(substr($date,0,4)) == 0 || trim($date)==''){
			return '-';
		}
		else{
			return substr($date,8,2).$delimiteur.substr($date,5,2).$delimiteur.substr($date,0,4);
		}
	}
	
	public static function format_datetime($date){
		if(round(substr($date,0,4)) == 0 || trim($date)==''){
			return '-';
		}
		else{
			return substr($date,8,2).'/'.substr($date,5,2).'/'.substr($date,0,4).' '.substr($date,11,2).'h'.substr($date,14,2);
		}
	}

	public static function ecart_dates_jours($date1,$date2='today'){
		$d1 = new DateTime($date1); 
		if($date2=='' || $date2=='today'){
			$d2 = new DateTime();
		}
		else{
			$d2 = new DateTime($date2);
		}
		$diff = $d1->diff($d2);
		return ($diff->d + $diff->m * 30 + $diff->y * 365); // Ecart en jours
	}

	public static function dates_to_period ( $date_debut, $date_fin ) {
		return array (
			DateFunctions::date_to_mysql_long($date_debut),
			DateFunctions::date_to_mysql_long($date_fin)
		);
	}

	public static function time_to_mysql_long($time){
		// EX : 14:30:25 -> 14:30:25.000000
		return $time.'000000';
	}

	public static function duree_to_mysql($time){
		// EX : 14:30:25 -> 14:30:25.000000
		$heure=(int)($time/60);
		if($heure>0){
			$min=$time%($heure*60);
		}
		else{
			$min=$time;
		}
		return $heure.":".$min.':00.000000';
	}

	// 2014-08-18 ---> Lundi 18 Août 2014
	public static function date_mot($date)
	{ 
		$date_time=new DateTime($date);
		$date_en=date_format($date_time, 'l d F Y');
		$texte_en = array(
		    "Monday", "Tuesday", "Wednesday", "Thursday",
		    "Friday", "Saturday", "Sunday", "January",
		    "February", "March", "April", "May",
		    "June", "July", "August", "September",
		    "October", "November", "December"
		);
		$texte_fr = array(
		    "Lundi", "Mardi", "Mercredi", "Jeudi",
		    "Vendredi", "Samedi", "Dimanche", "Janvier",
		    "Février", "Mars", "Avril", "Mai",
		    "Juin", "Juillet", "Août", "Septembre",
		    "Octobre", "Novembre", "Décembre"
		);
		$date_fr=str_replace($texte_en,$texte_fr,$date_en);
		return $date_fr;
	}

	// public static function date_mot_to_sql($date,$heure)
	// {
	// 	$texte_fr = array(
	// 		"é","û","è",//permet de ne pas prendre en compte les fautes d'accents
	// 	    "Lundi", "Mardi", "Mercredi", "Jeudi",
	// 	    "Vendredi", "Samedi", "Dimanche", "Janvier",
	// 	    "Fevrier", "Mars", "Avril", "Mai",
	// 	    "Juin", "Juillet", "Aout", "Septembre",
	// 	    "Octobre", "Novembre", "Decembre",
	// 	);
	// 	$texte_sql = array(
	// 		"e","u","e",
	// 	    "", "", "", "",
	// 	    "", "", "", "01",
	// 	    "02", "03", "04", "05",
	// 	    "06", "07", "08", "09",
	// 	    "10", "11", "12"
	// 	);
	// 	$date=str_replace($texte_fr,$texte_sql,$date);
	// 	$date=trim($date);

	// 	$heure=str_replace('h',':',$heure);

	// 	return array('date_d' => substr($date,0,2),
	//        			'date_m' => substr($date,3,2),
	//        			'date_y' => substr($date,6,4),
	//        			'heure'=>$heure);
	// }

}