<?php
	
/**
 * Provides a very/home/callimed/site/app/library/Resizer.php simple way to resize an image.
 *
 * Credits to Jarrod Oberto.
 * Jarrod wrote a tutorial on NetTuts.
 * http://net.tutsplus.com/tutorials/php/image-resizing-made-easy-with-php/
 *
 * I only turned it into a Laravel bundle.
 *
 * @package Resizer
 * @version 1.0
 * @author Maikel D (original author Jarrod Oberto)
 * @link
 * @example
 * 		Resizer::open( mixed $file )
 *			->resize( int $width , int $height , string 'exact, portrait, landscape, auto or crop' )
 *			->save( string 'path/to/file.jpg' , int $quality );
 *
 *		// Resize and save an image.
 * 		Resizer::open( Input::file('field_name') )
 *			->resize( 800 , 600 , 'crop' )
 *			->save( 'path/to/file.jpg' , 100 );
 *
 *		// Recompress an image.
 *		Resizer::open( 'path/to/image.jpg' )
 *			->save( 'path/to/new_image.jpg' , 60 );
 */
class Resizer {
	
	/**
	 * Store the image resource which we'll modify
	 * @var Resource
	 */
	private $image;
	
	/**
	 * Original width of the image we're modifying
	 * @var int
	 */
	private $width;
	
	/**
	 * Original height of the image we're modifying
	 * @var int
	 */
	private $height;
	
	/**
	 * Store the resource of the resized image
	 * @var Resource
	 */
	private $image_resized;
	
	/**
	 * Instantiates the Resizer and receives the path to an image we're working with
	 * @param mixed $file The file array provided by Laravel's Input::file('field_name') or a path to a file
	 */
	function __construct( $file )
	{
		// Open up the file
		$this->image = $this->open_image( $file );
		$this->file = $file;
		// Get width and height of our image
		$this->width  = imagesx( $this->image );
		$this->height = imagesy( $this->image );
	}
	
	/**
	 * Static call, Laravel style.
	 * Returns a new Resizer object, allowing for chainable calls
	 * @param  mixed $file The file array provided by Laravel's Input::file('field_name') or a path to a file
	 * @return Resizer
	 */
	public static function open( $file )
	{
		return new Resizer( $file );
	}
	
	/**
	 * Resizes and/or crops an image
	 * @param  int    $new_width  The width of the image
	 * @param  int    $new_height The height of the image
	 * @param  string $option     Either exact, portrait, landscape, auto or crop.
	 * @return [type]
	 */
	public function resize( $new_width , $new_height , $option = 'auto' )
	{
		// Get optimal width and height - based on $option.
		$option_array = $this->get_dimensions( $new_width , $new_height , $option );
		
		$optimal_width	= $option_array['optimal_width'];
		$optimal_height	= $option_array['optimal_height'];
		
		// Resample - create image canvas of x, y size.
		$this->image_resized = imagecreatetruecolor( $optimal_width , $optimal_height );
		
		// soucis d'orientation sur certains exifs
		//$exif = exif_read_data($source);
		//$ort = $exif['Orientation'];
		
		// Retain transparency for PNG and GIF files
		imagecolortransparent( $this->image_resized , imagecolorallocatealpha( $this->image_resized , 255 , 255 , 255 , 127 ) );
		imagealphablending( $this->image_resized , false );
		imagesavealpha( $this->image_resized , true );
		
		// Create the new image.
		imagecopyresampled( $this->image_resized , $this->image , 0 , 0 , 0 , 0 , $optimal_width , $optimal_height , $this->width , $this->height );
		
		// if option is 'crop' or 'fit', then crop too
		if ( $option == 'crop' || $option == 'fit' || $option == 'cropleft' ) {
			if($option == 'cropleft') {
				$this->crop( $optimal_width , $optimal_height , $new_width , $new_height , 'left' );
			} else {
				$this->crop( $optimal_width , $optimal_height , $new_width , $new_height , NULL );
			}
		}
		
		// Return $this to allow calls to be chained
		return $this;
	}
	
	public function watermark_image($display = true){
		
		// Ajoute le filigrane visible si besoin
		
		if($display)
		{
			if ( !$this->image_resized ) {$this->image_resized = $this->image;}
			
			$tmp_file = 'public/image/nicotmp'.rand(1,100000000000).'.jpg';
			imagejpeg( $this->image_resized , $tmp_file , 100 );
			$tmp_img = $this->open_image($tmp_file);
			@unlink($tmp_file);
			$this->image_resized = $tmp_img;
			
			$width = imagesx($this->image_resized);
			$height = imagesy($this->image_resized);
			
			if ($width == 215 && $height == 156) {
				$stamp = imagecreatefrompng('public/image/watermark-215-156.png');
			} elseif ($width == 1200 && $height == 700) {
				$stamp = imagecreatefrompng('public/image/watermark-1200-700.png');
			} else {
				$stamp = imagecreatefrompng('public/image/watermark-700-480.png');
			}
		
			$stamp_width = imagesx($stamp);
			$stamp_height = imagesy($stamp);
			$black = imagecolorallocate($im, 0, 0, 0);
			imagecolortransparent( $stamp , $black );

			//imagealphablending($stamp, true);

			imagecopy($this->image_resized, $stamp, imagesx($this->image_resized) - $stamp_width, imagesy($this->image_resized) - $stamp_height, 0, 0, imagesx($stamp), imagesy($stamp));
		}
		return $this;
	}
	

	public function watermark($new_width, $new_height, $text = 'immo-neo.com ©',$display=true){
		
		// Ajoute le filigrane visible si besoin
		
		if($display)
		{
			if ( !$this->image_resized ) {$this->image_resized = $this->image;}
			
			$width = imagesx($this->image_resized);
			$height = imagesy($this->image_resized);
						
			if ($new_height > $new_width) {
				$font_width = ceil(((40 / 920) * $new_width)/0.4);
				$watermark_width = ceil(((30*strlen($text) / 920 * $new_width)/0.4));
			} else {
				$font_width = ceil((40 / 920) * $width);
				$watermark_width = ceil(30*strlen($text) / 920 * $width);
			}
			
			$watermark_height = 92;
						
			// First we create our watermark image manually from GD
			$im = imagecreatetruecolor(55, 30);
			$black = imagecolorallocate($im, 0, 0, 0);
			$watermark = imagecreatetruecolor($watermark_width, $watermark_height);
			imagecolortransparent($watermark,$black);
			//imagestring($watermark, 5, 20, 20, $text, 0xFFFFFF);
			
			//$font = 'public/image/arial.ttf';
			$font = 'public/font/Ubuntu-R.ttf';
			$font_color =  0xFFFFFF;
			imagettftext($watermark, $font_width, 0, 0, 92, -$font_color, $font, $text);
			
			// Position du watermark au centre
			$position_center = ceil(($width - $watermark_width) / 2)+$watermark_width/20;
			$position_middle = ceil(($height - $watermark_height) / 2)-$watermark_height/2.9;
			
			// Merge du watermark avec la photo d'origine
			imagecopymerge($this->image_resized, $watermark, $position_center, $position_middle, 0, 0, $width, $height, 60);
		}
		return $this;
	}

	public function invisible_watermark($text){
		
		// Pour voir le copyright caché : ouvrir un calque sous photoshop avec la photo originale sans CP, puis un autre calque au dessus avec le copyright.
		// Faire "fusion" avec le mode division : on voit le copyright apparaitre
		
		$watermark_width = 170;
		$watermark_height = 40;
		$marge_right = 10;
		$marge_bottom = 10;
		
		$width = imagesx($this->image);
		$height = imagesy($this->image);
		
		$nb_watermarks_largeur = floor($width/$watermark_width);
		$nb_watermarks_hauteur = floor($height/$watermark_height);
		
		// First we create our watermark image manually from GD
		$im = imagecreatetruecolor(55, 30);
		$black = imagecolorallocate($im, 0, 0, 0);
		$watermark = imagecreatetruecolor($watermark_width, $watermark_height);
		imagecolortransparent($watermark,$black);
		//imagestring($watermark, 5, 20, 20, $text, 0xFFFFFF);
		
		$font = 'public/image/arial.ttf';
		$font_color =  0xCCCCCC;
		imagettftext($watermark, 15, 0, 10, 20, -$font_color, $font, $text);
		
		// Then we create a full watermark zone (total image size)
		$watermark_container = imagecreatetruecolor($width, $height);
		imagecolortransparent($watermark_container,$black);
		
		for($i=1;$i<=$nb_watermarks_largeur;$i++){
			for($j=1;$j<=$nb_watermarks_hauteur;$j++){
				if($j%2==0){$addmargin = 40;}else{$addmargin = 0;}
				imagecopymerge($watermark_container, $watermark, imagesx($this->image) - $addmargin - $watermark_width*$i - $marge_right, imagesy($this->image) - $watermark_height*$j - $marge_bottom, 0, 0, imagesx($watermark), imagesy($watermark), 100);
			}
		}
		
		// Merge des watermarks avec la photo - par défaut opacité à 3%, si on monte plus ça se voit
		imagecopymerge($this->image, $watermark_container, 0, 0, 0, 0, $width, $height, 3);

		return $this;
	}
	
	/**
	 * Save the image based on its file type.
	 * @param  string $save_path     Where to save the image
	 * @param  int    $image_quality The output quality of the image
	 * @return boolean
	 */
	public function save( $save_path , $image_quality = 95 )
	{
		// If the image wasn't resized, fetch original image.
		if ( !$this->image_resized ) {$this->image_resized = $this->image;}
		
		// Get extension of the output file
		$extension = strtolower( File::extension($save_path) );
		
		// Create and save an image based on it's extension
		switch( $extension )
		{
			case 'jpg':
			case 'jpeg':
				if ( imagetypes() & IMG_JPG ) {
					imagejpeg( $this->image_resized , $save_path , $image_quality );
				}
				break;
				
			case 'gif':
				if ( imagetypes() & IMG_GIF ) {
					imagegif( $this->image_resized , $save_path );
				}
				break;
				
			case 'png':
				// Scale quality from 0-100 to 0-9
				$scale_quality = round( ($image_quality/100) * 9 );
				
				// Invert quality setting as 0 is best, not 9
				$invert_scale_quality = 9 - $scale_quality;
				
				if ( imagetypes() & IMG_PNG ) {
					imagepng( $this->image_resized , $save_path , $invert_scale_quality );
				}
				break;
				
			default:
				return false;
				break;
		}
		
		// Remove the resource for the resized image
		//imagedestroy( $this->image_resized );
		
		return $this;
	}
	
	// Sors la photo sans l'enregister - Nico 2013
	public function output_img( $save_path, $image_quality = 95 )
	{
		// If the image wasn't resized, fetch original image.
		if ( !$this->image_resized ) {
			$this->image_resized = $this->image;
		}
		
		// Get extension of the output file
		$extension = strtolower( File::extension($save_path) );
		
		// Create and save an image based on it's extension
		switch( $extension )
		{
			case 'jpg':
			case 'jpeg':
				if ( imagetypes() & IMG_JPG ) {
					imagejpeg( $this->image_resized , NULL , $image_quality );
				}
				break;
				
			case 'gif':
				if ( imagetypes() & IMG_GIF ) {
					imagegif( $this->image_resized , NULL );
				}
				break;
				
			case 'png':
				// Scale quality from 0-100 to 0-9
				$scale_quality = round( ($image_quality/100) * 9 );
				
				// Invert quality setting as 0 is best, not 9
				$invert_scale_quality = 9 - $scale_quality;
				
				if ( imagetypes() & IMG_PNG ) {
					imagepng( $this->image_resized , NULL , $invert_scale_quality );
				}
				break;
				
			default:
				return false;
				break;
		}
		
		// Remove the resource for the resized image
		imagedestroy( $this->image_resized );
		
		return true;
	}
	
	/**
	 * Open a file, detect its mime-type and create an image resrource from it.
	 * @param  array $file Attributes of file from the $_FILES array
	 * @return mixed
	 */
	private function open_image( $file )
	{
		$filemime = new Symfony\Component\HttpFoundation\File\File($file);
		$mime = $filemime->getMimeType();
		
		// If $file isn't an array, we'll turn it into one
		if ( !is_array($file) ) {
			$file = array(
				'type'		=> $mime,
				'tmp_name'	=> $file
			);
		}
		
		$mime = $file['type'];
		$file_path = $file['tmp_name'];
		
		switch ( $mime )
		{
			case 'image/pjpeg': // IE6
			case 'image/jpeg':	$img = @imagecreatefromjpeg( $file_path );	break;
			case 'image/jpg':	$img = @imagecreatefromjpeg( $file_path );	break;
			case 'image/gif':	$img = @imagecreatefromgif( $file_path );	break;
			case 'image/png':	$img = @imagecreatefrompng( $file_path );	break;
			default:				$img = false;								break;
		}
		
		return $img;
	}
	
	/**
	 * Return the image dimentions based on the option that was chosen.
	 * @param  int    $new_width  The width of the image
	 * @param  int    $new_height The height of the image
	 * @param  string $option     Either exact, portrait, landscape, auto or crop.
	 * @return array
	 */
	private function get_dimensions( $new_width , $new_height , $option )
	{
		switch ( $option )
		{
			case 'exact':
				$optimal_width	= $new_width;
				$optimal_height	= $new_height;
				break;
			case 'portrait':
				$optimal_width	= $this->get_size_by_fixed_height( $new_height );
				$optimal_height	= $new_height;
				break;
			case 'landscape':
				$optimal_width	= $new_width;
				$optimal_height	= $this->get_size_by_fixed_width( $new_width );
				break;
			case 'auto':
				$option_array	= $this->get_size_by_auto( $new_width , $new_height );
				$optimal_width	= $option_array['optimal_width'];
				$optimal_height	= $option_array['optimal_height'];
				break;
			case 'fit':
				$option_array	= $this->get_size_by_fit( $new_width , $new_height );
				$optimal_width	= $option_array['optimal_width'];
				$optimal_height	= $option_array['optimal_height'];
				break;
			case 'crop':
				$option_array	= $this->get_optimal_crop( $new_width , $new_height );
				$optimal_width	= $option_array['optimal_width'];
				$optimal_height	= $option_array['optimal_height'];
				break;
			case 'cropleft':
				$option_array	= $this->get_optimal_cropleft( $new_width , $new_height );
				$optimal_width	= $option_array['optimal_width'];
				$optimal_height	= $option_array['optimal_height'];
				break;
		}
		
		return array(
			'optimal_width'		=> $optimal_width,
			'optimal_height'	=> $optimal_height
		);
	}
	
	/**
	 * Returns the width based on the image height
	 * @param  int    $new_height The height of the image
	 * @return int
	 */
	private function get_size_by_fixed_height( $new_height )
	{
		$ratio		= $this->width / $this->height;
		$new_width	= $new_height * $ratio;
		
		return $new_width;
	}
	
	/**
	 * Returns the height based on the image width
	 * @param  int    $new_width The width of the image
	 * @return int
	 */
	private function get_size_by_fixed_width( $new_width )
	{
		$ratio		= $this->height / $this->width;
		$new_height	= $new_width * $ratio;
		
		return $new_height;
	}
	
	/**
	 * Checks to see if an image is portrait or landscape and resizes accordingly.
	 * @param  int    $new_width  The width of the image
	 * @param  int    $new_height The height of the image
	 * @return array
	 */
	private function get_size_by_auto( $new_width , $new_height )
	{
		// Image to be resized is wider (landscape)
		if ( $this->height < $this->width )
		{
			$optimal_width	= $new_width;
			$optimal_height	= $this->get_size_by_fixed_width( $new_width );
		}
		// Image to be resized is taller (portrait)
		else if ( $this->height > $this->width )
		{
			$optimal_width	= $this->get_size_by_fixed_height( $new_height );
			$optimal_height	= $new_height;
		}
		// Image to be resizerd is a square
		else
		{
			if ( $new_height < $new_width )
			{
				$optimal_width	= $new_width;
				$optimal_height	= $this->get_size_by_fixed_width( $new_width );
			}
			else if ( $new_height > $new_width )
			{
				$optimal_width	= $this->get_size_by_fixed_height( $new_height );
				$optimal_height	= $new_height;
			}
			else
			{
				// Sqaure being resized to a square
				$optimal_width	= $new_width;
				$optimal_height	= $new_height;
			}
		}
		
		return array(
			'optimal_width'		=> $optimal_width,
			'optimal_height'	=> $optimal_height
		);
	}
	
	/**
	 * Resizes an image so it fits entirely inside the given dimensions.
	 * @param  int    $new_width  The width of the image
	 * @param  int    $new_height The height of the image
	 * @return array
	 */
	private function get_size_by_fit( $new_width , $new_height )
	{
		
		$height_ratio	= $this->height / $new_height;
		$width_ratio	= $this->width /  $new_width;
		
		$max = max( $height_ratio , $width_ratio );
		
		return array(
			'optimal_width'		=> $this->width / $max,
			'optimal_height'	=> $this->height / $max,
		);
	}
	
	/**
	 * Attempts to find the best way to crop. Whether crop is based on the
	 * image being portrait or landscape.
	 * @param  int    $new_width  The width of the image
	 * @param  int    $new_height The height of the image
	 * @return array
	 */
	private function get_optimal_crop( $new_width , $new_height )
	{
		$height_ratio	= $this->height / $new_height;
		$width_ratio	= $this->width /  $new_width;
		
		if ( $height_ratio < $width_ratio ) {
			$optimal_ratio = $height_ratio;
		} else {
			$optimal_ratio = $width_ratio;
		}
		
		$optimal_height	= $this->height / $optimal_ratio;
		$optimal_width	= $this->width  / $optimal_ratio;
		
		return array(
			'optimal_width'		=> $optimal_width,
			'optimal_height'	=> $optimal_height
		);
	}
	
	private function get_optimal_cropleft( $new_width , $new_height )
	{
		$height_ratio	= $this->height / $new_height;
		$width_ratio	= $this->width /  $new_width;
		
		if ( $height_ratio < $width_ratio ) {
			$optimal_ratio = $height_ratio;
		} else {
			$optimal_ratio = $width_ratio;
		}
		
		$optimal_height	= $this->height / $optimal_ratio;
		$optimal_width	= $this->width  / $optimal_ratio;
		
		return array(
			'optimal_width'		=> $optimal_width,
			'optimal_height'	=> $optimal_height
		);
	}
	
	/**
	 * Crops an image from its center
	 * @param  int    $optimal_width  The width of the image
	 * @param  int    $optimal_height The height of the image
	 * @param  int    $new_width      The new width
	 * @param  int    $new_height     The new height
	 * @return true
	 */
	private function crop( $optimal_width , $optimal_height , $new_width , $new_height, $position )
	{
		// Position
		if( $position == 'left' ){
			$crop_start_x = 10;
			$crop_start_y = ( $optimal_height / 2 ) - ( $new_height / 2 );
		} else {
			$crop_start_x = ( $optimal_width  / 2 ) - ( $new_width  / 2 );
			$crop_start_y = ( $optimal_height / 2 ) - ( $new_height / 2 );
		}
		
		$crop = $this->image_resized;
		
		$dest_offset_x	= max( 0, -$crop_start_x );
		$dest_offset_y	= max( 0, -$crop_start_y );
		$crop_start_x	= max( 0, $crop_start_x );
		$crop_start_y	= max( 0, $crop_start_y );
		$dest_width		= min( $optimal_width, $new_width );
		$dest_height	= min( $optimal_height, $new_height );
		
		// Now crop from center to exact requested size
		$this->image_resized = imagecreatetruecolor( $new_width , $new_height );
		
		imagealphablending( $crop , true );
		imagealphablending( $this->image_resized , false );
		imagesavealpha( $this->image_resized , true );
		
		imagefilledrectangle( $this->image_resized , 0 , 0 , $new_width , $new_height,
			imagecolorallocatealpha( $this->image_resized , 255 , 255 , 255 , 127 )
		);
		
		imagecopyresampled( $this->image_resized , $crop , $dest_offset_x , $dest_offset_y , $crop_start_x , $crop_start_y , $dest_width , $dest_height , $dest_width , $dest_height );
		
		return true;
	}
	
}
