<?php

use Illuminate\Auth\UserTrait;
use Illuminate\Auth\UserInterface;
use Illuminate\Auth\Reminders\RemindableTrait;
use Illuminate\Auth\Reminders\RemindableInterface;

class User extends Eloquent implements UserInterface, RemindableInterface {

	use UserTrait, RemindableTrait;

	// Add your validation rules here
	public static $rules = [
	    'email'    		=> 'required',
	    'last_name' 	=> 'required',
	    'first_name' 	=> 'required'
	];

	// Don't forget to fill this array
	protected $fillable = ['email', 'password', 'last_name', 'first_name', 'phone', 'admin'];

	/**
	 * The database table used by the model.
	 *
	 * @var string
	 */
	protected $table = 'users';

	/**
	 * The attributes excluded from the model's JSON form.
	 *
	 * @var array
	 */
	protected $hidden = array('password', 'remember_token');

    /**
     * Set the password for the user.
     *
     * @return void
     */
    public function setPasswordAttribute($value)
    {
        $this->attributes['password'] = Hash::make($value);
    }
    
    public function has_permission($id)
	{
		foreach($this->roles as $r)
		{
			if($r->id == $id)
			{
				return true;
				break;
			}
		}
		return false;
	}
    
    public function roles()
	{
		return $this->belongsToMany('Role');
	}
	
	public function country()
	{
		return $this->belongsTo('Country');
	}

}
