<?php

/*
|--------------------------------------------------------------------------
| Language Detection
|--------------------------------------------------------------------------
*/

// Language
$languages = array('fr', 'en');
$locale = Request::segment(1);
if(in_array($locale, $languages)){
    \App::setLocale($locale);
}else{
    $locale = 'fr';
	\App::setLocale('fr');
}

if(Request::segment(1) == $_ENV['admin-url']) {
    $locale = 'fr';
	\App::setLocale('fr');
}

// Store language in session
$language = Language::whereShort($locale)->first();
Session::put('language', $language);
Session::put('languages', $languages);
Session::put('lang', $language->short);

/*
|--------------------------------------------------------------------------
| Application Routes
|--------------------------------------------------------------------------
|
| Here is where you can register all of the routes for an application.
| It's a breeze. Simply tell Laravel the URIs it should respond to
| and give it the Closure to execute when that URI is requested.
|
*/

// Photos de la gallerie
Route::get('photogallery/{width}/{height}/{name}', array('as'=>'photogallery',function($width,$height,$name,$type="crop"){
	$image_path = public_path().'/uploads/photos/gallery/'.$name;
    if(!file_exists($image_path)){return Redirect::route('home');}
    else{
    	header('content-type: image/png');
	    Resizer::open($image_path)
			->resize($width, $height, $type)
			->output_img($image_path,70); die();
    }
}));

Route::get('photoslider/{width}/{height}/{name}', array('as'=>'photoslider',function($width,$height,$name,$type="crop"){
	$image_path = public_path().'/image/'.$name;
    if(!file_exists($image_path)){return Redirect::route('home');}
    else{
    	header('content-type: image/png');
	    Resizer::open($image_path)
			->resize($width, $height, $type)
			->output_img($image_path,70); die();
    }
}));

// Routes en étant identifié (customers)
Route::group(array('before' => 'customer_auth'), function(){
	
	Route::get('logout_front', array('as' => 'logout_front', 'uses' => 'CustomerareaController@logout'));
	//Route::get(trans('site.route_espaceclient'), ['as'=>'login_front_customer', 'uses'=>'CustomerareaLoggedController@index']);
	//Route::get(trans('site.route_espaceclient').'/'.trans('site.route_espaceclientuser'), ['as'=>'login_front_profil', 'uses'=>'CustomerareaLoggedController@profil']);
	//Route::put(trans('site.route_espaceclient').'/'.trans('site.route_espaceclientuser').'/post', ['as'=>'login_front_profil_post', 'uses'=>'CustomerareaLoggedController@profilupdate']);
	
});

// Paypal
Route::any('paypal', 'PaymentsController@ipn');
Route::get('/', ['as' => 'home', 'uses' => 'HomeController@index']);
Route::get('sitemap-index.xml', ['as' => 'sitemap_xml', 'uses' => 'SitemapController@get_xmlsitemap']);

/*
|--------------------------------------------------------------------------
| Session Routes
|--------------------------------------------------------------------------
*/

Route::group(['before' => 'guest'], function(){

    // Auth
    Route::get($_ENV['login-url'], ['as' => 'login', 'uses' => 'SessionsController@create']);
    Route::post($_ENV['login-url'], ['as' => 'login', 'uses' => 'SessionsController@store']);

});

Route::group(['before' => 'auth'], function(){

    // Auth
    Route::get('logout', ['as' => 'logout', 'uses' => 'SessionsController@destroy']);

});

/*
|--------------------------------------------------------------------------
| Admin Routes
|--------------------------------------------------------------------------
*/

Route::group(['prefix' => $_ENV['admin-url'], 'before' => 'auth'], function(){

	// Dashboard
	Route::get('/', ['as' => 'admin', 'uses' => 'DashboardController@index']);
	
	// Users
    Route::get('users/{id}/destroy', ['as' => $_ENV['admin-url'].'.users.destroy', 'uses' => 'UsersController@destroy']);
    Route::resource('users', 'UsersController', ['only' => ['create', 'update', 'show', 'store', 'index']]);
    

	Route::get('registrations', ['as' => $_ENV['admin-url'].'.registrations.index', 'uses' => 'RegistrationsController@index']);
	Route::get('registrations/{id}', ['as' => $_ENV['admin-url'].'.registrations.registration', 'uses' => 'RegistrationsController@registration']);
	Route::get('registrations/export/csv', ['as' => $_ENV['admin-url'].'.registrations.export', 'uses' => 'RegistrationsController@export']);
	Route::post('registration/delete', ['as' => $_ENV['admin-url'].'.registrations.delete', 'uses' => 'RegistrationsController@delete']);
	
	
	Route::get('photos', ['as' => $_ENV['admin-url'].'.photos.index', 'uses' => 'PhotosController@index']);
	Route::post('photos/order', ['as' => $_ENV['admin-url'].'.photos.order', 'uses' => 'PhotosController@order']);
	Route::post('photos/save', ['as' => $_ENV['admin-url'].'.photos.save', 'uses' => 'PhotosController@save']);
	Route::any('photo/upload', ['as' => $_ENV['admin-url'].'.photos.upload', 'uses' => 'PhotosController@upload']);
	Route::post('photo/delete', ['as' => $_ENV['admin-url'].'.photos.delete', 'uses' => 'PhotosController@delete']);
	
	Route::get('questions', ['as' => $_ENV['admin-url'].'.questions.index', 'uses' => 'QuestionsController@index']);
	Route::post('questions/retrieve-infos', ['as' => $_ENV['admin-url'].'.questions.retrieve-infos', 'uses' => 'QuestionsController@question_retreive_infos']);
	Route::post('questions/create', ['as' => $_ENV['admin-url'].'.questions.create', 'uses' => 'QuestionsController@create_question']);
	Route::post('questions/update', ['as' => $_ENV['admin-url'].'.questions.update', 'uses' => 'QuestionsController@update_question']);
	Route::post('questions/delete', ['as' => $_ENV['admin-url'].'.questions.delete', 'uses' => 'QuestionsController@delete_question']);
	Route::post('questions-theme/create', ['as' => $_ENV['admin-url'].'.questions-theme.create', 'uses' => 'QuestionsController@create_question_theme']);
	Route::post('questions-theme/update', ['as' => $_ENV['admin-url'].'.questions-theme.update', 'uses' => 'QuestionsController@update_question_theme']);
	Route::post('questions-theme/delete', ['as' => $_ENV['admin-url'].'.questions-theme.delete', 'uses' => 'QuestionsController@delete_question_theme']);
	
    /*
    // Demandes de contact
    Route::get('contacts/{id}/destroy', ['as' => $_ENV['admin-url'].'.contacts.destroy', 'uses' => 'ContactsController@destroy']);
    Route::resource('contacts', 'ContactsController', ['only' => ['update', 'show', 'index']]);
    */
    
});

if($locale == 'fr') {
	Route::get('/fr', ['as' => 'home', 'uses' => 'HomeController@index']);
	lang_routes();
}
else {
	Route::group(array('prefix' => $locale), function()
	{
		lang_routes();
	});
}

function lang_routes() {
	Route::get('/', ['as' => 'home', 'uses' => 'HomeController@index']);
	
	Route::get('/registration', ['as' => 'registration', 'uses' => 'RegistrationController@index']);
	Route::post('/registration', ['as' => 'post_registration', 'uses' => 'RegistrationController@registration']);
	
	Route::get('/agenda', ['as' => 'agenda', 'uses' => 'HomeController@agenda']);	
	Route::get('/practical-information/{any}', ['as' => 'practical_information', 'uses' => 'HomeController@practical_information']);
	Route::get('/gallery', ['as' => 'gallery', 'uses' => 'HomeController@gallery']);	
	Route::get('/documents', ['as' => 'documents', 'uses' => 'HomeController@documents']);
	
	Route::get('/faq', ['as' => 'faq', 'uses' => 'HomeController@faq']);
	Route::post('/post-question', ['as' => 'post_question', 'uses' => 'HomeController@post_question']);
	
	Route::get('/contact', ['as' => 'contact', 'uses' => 'HomeController@contact']);
	
	Route::get('/ie', ['as' => 'ie', 'uses' => 'HomeController@ie']);
	
	Route::get('{any}', function(){return Redirect::route('home');});
}

Route::filter('customer_auth', function()
{
	$customer_id = round(Session::get('customer_id'));
	// Si le user n'est pas identifié
    if($customer_id<=0 || !$customer = Customer::find($customer_id)){
    	Session::put('back_url', Request::path());
    	Session::put('current_url', Request::path());
    	return Redirect::to('/?login=true');
    }
});

/*
|--------------------------------------------------------------------------
| Error Routes
|--------------------------------------------------------------------------
*/

App::error(function(Illuminate\Database\Eloquent\ModelNotFoundException $exception)
{
    // Ugly should do "return App::abort(404);"
    return Response::view('errors.404', array('url' => Request::url()), 404);
});

App::missing(function($exception)
{
    //return Response::view('errors.404', array('url' => Request::url()), 404);
	return Redirect::to('/'.Session::get('lang')); // A verifier
});
