/**
 * @name		jQuery Countdown Plugin
 * @author		Martin Angelov
 * @version 	1.0
 * @url			http://tutorialzine.com/2011/12/countdown-jquery/
 * @license		MIT License
 */

(function($){
	
	// Number of seconds in every time division
	var days	= 24*60*60,
		hours	= 60*60,
		minutes	= 60,
		annees  = 31536000;
	
	// Creating the plugin
	$.fn.countdown = function(prop){
		
		var options = $.extend({
			callback	: function(){},
			timestamp	: 0
		},prop);
		
		var left, a, d, h, m, s, positions;

		// Initialize the plugin
		init(this, options);
		
		positions = this.find('.position');
		
		(function tick(){
			
			// Time left
			left = Math.floor((new Date() - options.timestamp)*0.001);
			//left = Math.floor( (new Date().getTime() - options.timestamp)/1000 );
			
			day = parseInt( parseInt( left / 86400 ) % 365 ) - Math.floor( parseInt( new Date().getFullYear() - options.timestamp.getFullYear() ) / 4 );
			if(day<0){
				d = 365 + day;
				a = parseInt( left / 31536000 ) -1;
			} else {
				d = day;
				a = parseInt( left / 31536000 );
			}
			a = a;
			d = d;
			h = parseInt( left / 3600 ) % 24;
			m = parseInt( left / 60 ) % 60;
			s = left % 60;
			
			// Calling an optional user supplied callback
			options.callback(a, d, h, m, s);
			
			// Scheduling another call of this function in 1s
			setTimeout(tick, 1000);
		})();
		
		return this;
	};


	function init(elem, options){
		elem.addClass('countdownHolder');

		// Creating the markup inside the container
		$.each(['Days','Hours','Minutes','Seconds'],function(i){
			$('<span class="count'+this+'">').html(
				'<span class="position">\
					<span class="digit static">0</span>\
				</span>\
				<span class="position">\
					<span class="digit static">0</span>\
				</span>'
			).appendTo(elem);
			
			if(this!="Seconds"){
				elem.append('<span class="countDiv countDiv'+i+'"></span>');
			}
		});

	}

	// Creates an animated transition between the two numbers
	function switchDigit(position,number){
		
		var digit = position.find('.digit')
		
		if(digit.is(':animated')){
			return false;
		}
		
		if(position.data('digit') == number){
			// We are already showing this number
			return false;
		}
		
		position.data('digit', number);
		
		var replacement = $('<span>',{
			'class':'digit',
			css:{
				top:'-2.1em',
				opacity:0
			},
			html:number
		});
		
		// The .static class is added when the animation
		// completes. This makes it run smoother.
		
		digit
			.before(replacement)
			.removeClass('static')
			.animate({top:'2.5em',opacity:0},'fast',function(){
				digit.remove();
			})

		replacement
			.delay(100)
			.animate({top:0,opacity:1},'fast',function(){
				replacement.addClass('static');
			});
	}
	
})(jQuery);

function rebours(element0, element1, element2, element3, element4, date){
	var note1 	= $(element1),
		note2 	= $(element2),
		note3 	= $(element3),
		note4 	= $(element4),
		note0 	= $(element0),
		ts 		= (date); // Année, Mois-1, Jour, Heure, Min, Sec
		
	$('#countdown').countdown({
		timestamp	: ts,
		callback	: function(annees, days, hours, minutes, seconds){
			
			note0.html(annees);
			note1.html(days);
			note2.html(hours);
			note3.html(minutes);
			note4.html(seconds);
		}
	});
}